#[repr(u8)]pub enum ColorComponent<ValueType> {
None,
Value(ValueType),
ChannelKeyword(ChannelKeyword),
Calc(Box<CalcNode>),
AlphaOmitted,
}Expand description
A single color component.
Variants
None
The “none” keyword.
Value(ValueType)
A absolute value.
ChannelKeyword(ChannelKeyword)
A channel keyword, e.g. r, l, alpha, etc.
Calc(Box<CalcNode>)
A calc() value.
AlphaOmitted
Used when alpha components are not specified.
Implementations
Sourceimpl<ValueType> ColorComponent<ValueType>
impl<ValueType> ColorComponent<ValueType>
Sourceimpl<ValueType: ColorComponentType> ColorComponent<ValueType>
impl<ValueType: ColorComponentType> ColorComponent<ValueType>
Sourcepub fn parse<'i, 't>(
context: &ParserContext<'_>,
input: &mut Parser<'i, 't>,
allow_none: bool,
allowed_channel_keywords: ChannelKeyword,
) -> Result<Self, ParseError<'i>>
pub fn parse<'i, 't>( context: &ParserContext<'_>, input: &mut Parser<'i, 't>, allow_none: bool, allowed_channel_keywords: ChannelKeyword, ) -> Result<Self, ParseError<'i>>
Parse a single ColorComponent.
Sourcepub fn to_computed_value(
&self,
context: Option<&Context<'_>>,
origin_color: Option<&AbsoluteColor>,
) -> Self
pub fn to_computed_value( &self, context: Option<&Context<'_>>, origin_color: Option<&AbsoluteColor>, ) -> Self
Compute the component’s value against context, substituting color
channel references with the matching channel of origin_color when it is
provided (and already converted into this function’s color space).
If no (absolute) origin color is available, channel references are kept intact, so the component can still be resolved later at use-value time.