pub type OwnMap = IndexMap<Name, Option<ComputedValue>, BuildHasherDefault<PrecomputedHasher>>;Expand description
We use None in the value to represent a removed entry.
Aliased Type
pub struct OwnMap { /* private fields */ }pub type OwnMap = IndexMap<Name, Option<ComputedValue>, BuildHasherDefault<PrecomputedHasher>>;We use None in the value to represent a removed entry.
pub struct OwnMap { /* private fields */ }