pub struct RelativeSelectorInvalidator<'a, 'b, E>where
E: TElement + 'a,{
pub element: E,
pub quirks_mode: QuirksMode,
pub snapshot_table: Option<&'b SnapshotMap>,
pub invalidated: fn(E, &InvalidationResult),
pub sibling_traversal_map: SiblingTraversalMap<E>,
pub _marker: PhantomData<&'a ()>,
}Expand description
Overall invalidator for handling relative selector invalidations.
Fields
element: EElement triggering the invalidation.
quirks_mode: QuirksModeQuirks mode of the current invalidation.
snapshot_table: Option<&'b SnapshotMap>Snapshot containing changes to invalidate against. Can be None if it’s a DOM mutation.
invalidated: fn(E, &InvalidationResult)Callback to trigger when the subject element is invalidated.
sibling_traversal_map: SiblingTraversalMap<E>The traversal map that should be used to process invalidations.
_marker: PhantomData<&'a ()>Marker for ’a lifetime.
Implementations
Sourceimpl<'a, 'b, E> RelativeSelectorInvalidator<'a, 'b, E>where
E: TElement + 'a,
impl<'a, 'b, E> RelativeSelectorInvalidator<'a, 'b, E>where
E: TElement + 'a,
Sourcepub fn invalidate_relative_selectors_for_this<F>(
self,
stylist: &'a Stylist,
gather_dependencies: F,
)where
F: FnMut(&E, Option<OpaqueElement>, &'a CascadeData, QuirksMode, &mut RelativeSelectorDependencyCollector<'a, E>),
pub fn invalidate_relative_selectors_for_this<F>(
self,
stylist: &'a Stylist,
gather_dependencies: F,
)where
F: FnMut(&E, Option<OpaqueElement>, &'a CascadeData, QuirksMode, &mut RelativeSelectorDependencyCollector<'a, E>),
Gather relative selector dependencies for the given element, and invalidate as necessary.
Sourcepub fn invalidate_relative_selectors_for_dom_mutation(
self,
subtree: bool,
stylist: &'a Stylist,
inherited_search_path: ElementSelectorFlags,
operation: DomMutationOperation,
)
pub fn invalidate_relative_selectors_for_dom_mutation( self, subtree: bool, stylist: &'a Stylist, inherited_search_path: ElementSelectorFlags, operation: DomMutationOperation, )
Gather relative selector dependencies for the given element (And its subtree) that mutated, and invalidate as necessary.