pub struct Padding {
pub padding_top: T,
pub padding_right: T,
pub padding_bottom: T,
pub padding_left: T,
}Expand description
The Padding style struct.
Fields
padding_top: TThe padding-top computed value.
padding_right: TThe padding-right computed value.
padding_bottom: TThe padding-bottom computed value.
padding_left: TThe padding-left computed value.
Implementations
Sourceimpl Padding
impl Padding
Sourcepub fn set_padding_top(&mut self, v: T)
pub fn set_padding_top(&mut self, v: T)
Set padding-top.
Sourcepub fn copy_padding_top_from(&mut self, other: &Self)
pub fn copy_padding_top_from(&mut self, other: &Self)
Set padding-top from other struct.
Sourcepub fn reset_padding_top(&mut self, other: &Self)
pub fn reset_padding_top(&mut self, other: &Self)
Reset padding-top from the initial struct.
Sourcepub fn clone_padding_top(&self) -> T
pub fn clone_padding_top(&self) -> T
Get the computed value for padding-top.
Sourcepub fn padding_top_equals(&self, other: &Self) -> bool
pub fn padding_top_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for padding-top.
Sourcepub fn set_padding_right(&mut self, v: T)
pub fn set_padding_right(&mut self, v: T)
Set padding-right.
Sourcepub fn copy_padding_right_from(&mut self, other: &Self)
pub fn copy_padding_right_from(&mut self, other: &Self)
Set padding-right from other struct.
Sourcepub fn reset_padding_right(&mut self, other: &Self)
pub fn reset_padding_right(&mut self, other: &Self)
Reset padding-right from the initial struct.
Sourcepub fn clone_padding_right(&self) -> T
pub fn clone_padding_right(&self) -> T
Get the computed value for padding-right.
Sourcepub fn padding_right_equals(&self, other: &Self) -> bool
pub fn padding_right_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for padding-right.
Sourcepub fn set_padding_bottom(&mut self, v: T)
pub fn set_padding_bottom(&mut self, v: T)
Set padding-bottom.
Sourcepub fn copy_padding_bottom_from(&mut self, other: &Self)
pub fn copy_padding_bottom_from(&mut self, other: &Self)
Set padding-bottom from other struct.
Sourcepub fn reset_padding_bottom(&mut self, other: &Self)
pub fn reset_padding_bottom(&mut self, other: &Self)
Reset padding-bottom from the initial struct.
Sourcepub fn clone_padding_bottom(&self) -> T
pub fn clone_padding_bottom(&self) -> T
Get the computed value for padding-bottom.
Sourcepub fn padding_bottom_equals(&self, other: &Self) -> bool
pub fn padding_bottom_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for padding-bottom.
Sourcepub fn set_padding_left(&mut self, v: T)
pub fn set_padding_left(&mut self, v: T)
Set padding-left.
Sourcepub fn copy_padding_left_from(&mut self, other: &Self)
pub fn copy_padding_left_from(&mut self, other: &Self)
Set padding-left from other struct.
Sourcepub fn reset_padding_left(&mut self, other: &Self)
pub fn reset_padding_left(&mut self, other: &Self)
Reset padding-left from the initial struct.
Sourcepub fn clone_padding_left(&self) -> T
pub fn clone_padding_left(&self) -> T
Get the computed value for padding-left.
Sourcepub fn padding_left_equals(&self, other: &Self) -> bool
pub fn padding_left_equals(&self, other: &Self) -> bool
Whether self and other have the same computed value for padding-left.