CascadeLevel

Struct CascadeLevel 

pub struct CascadeLevel(/* private fields */);
The cascade level these rules are relevant at, as per13.

We store them as a bitfield with:

  • Shadow cascade order (4 bits). See ShadowCascadeOrder for details.
  • Importance bit. Whether the declaration was !important or not.
  • The CascadeOrigin of the declaration as per 1.

Presentational hints for SVG and HTML are in the “author-level zero-specificity” level, that is, right after user rules, and before author rules.

See also 4 for the Shadow DOM bits. We rely on the invariant that rules from outside the tree the element is in can’t affect the element.

The opposite is not true (i.e., :host and ::slotted) from an “inner” shadow tree may affect an element connected to the document or an “outer” shadow tree.

Implementations

Source

impl CascadeLevel

pub const ORIGIN_BITS: Self

The three bits that represent the CascadeOrigin.

pub const IMPORTANT: Self

Whether the declarations are !important or not.

pub const CASCADE_ORDER_BITS: Self

The three bits for cascade order absolute value. If you change this, please change CASCADE_ORDER_SHIFT accordingly.

pub const CASCADE_ORDER_SIGN: Self

The bit for the sign.

Source

impl CascadeLevel

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u8

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u8) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u8) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u8) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl CascadeLevel

pub const fn iter(&self) -> Iter<CascadeLevel>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<CascadeLevel>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl CascadeLevel

pub const CASCADE_ORDER_SHIFT: usize = 4

The shift that we apply to the cascade order.

pub const SAME_TREE_AUTHOR_NORMAL: Self

The author level at the same tree. Here for convenience to avoid duplicating it from C++.

pub fn new(origin: CascadeOrigin) -> Self

Returns a cascade level with a given origin.

pub fn origin(self) -> CascadeOrigin

Returns the cascade origin.

pub fn important(self) -> Self

Convert this level from “unimportant” to “important”.

pub fn unimportant(self) -> Self

Convert this level from “important” to “non-important”.

pub fn guard<'a>( &self, guards: &'a StylesheetGuards<'a>, ) -> &'a SharedRwLockReadGuard<'a>

Select a lock guard for this level

pub fn same_tree_author_important() -> Self

Returns the cascade level for author important declarations from the same tree as the element.

pub fn same_tree_author_normal() -> Self

Returns the cascade level for author normal declarations from the same tree as the element.

pub fn is_important(&self) -> bool

Returns whether this cascade level represents important rules of some sort.

pub fn importance(&self) -> Importance

Returns the importance relevant for this rule. Pretty similar to is_important.

pub fn is_animation(&self) -> bool

Returns whether this cascade level represents an animation rules.

pub fn is_tree(self) -> bool

Returns whether this cascade level is tree.

pub fn author_normal(shadow_cascade_order: ShadowCascadeOrder) -> Self

Returns an author normal cascade level with the given shadow cascade order.