PseudoElementCascadeType

Enum PseudoElementCascadeType 

pub enum PseudoElementCascadeType {
    Eager,
    Lazy,
    Precomputed,
}
This enumeration determines how a pseudo-element cascades.

Variants



Eager

Eagerly cascaded pseudo-elements are “normal” pseudo-elements (i.e. ::before and ::after). They inherit styles normally as another selector would do, and they’re computed as part of the cascade.

These kind of pseudo-elements require more up-front computation and storage and thus should used for public pseudo-elements that can be used on many element types (such as ::before and ::after).



Lazy

Lazy pseudo-elements are affected by selector matching, but they’re only computed when needed, and not before. They’re useful for general pseudo-elements that are not very common or that do not apply to many elements. For instance in Servo this is used for ::backdrop and ::marker.



Precomputed

Precomputed pseudo-elements skip the cascade process entirely, mostly as an optimisation since they are private pseudo-elements (like ::-servo-details-content).

This pseudo-elements are resolved on the fly using only global rules (rules of the form *|*), and applying them to the parent style so are mainly useful for user-agent stylesheets.