GenericAnchorFunctionFallback

Struct GenericAnchorFunctionFallback 

pub struct GenericAnchorFunctionFallback<L> {
    pub node: GenericCalcNode<L>,
    /* private fields */
}
Fallback type for anchor functions within calc(). Ideally, the fallback type is initial type of the property (e.g. GenericInset for left), but that causes circular reference. TODO(dshin, bug 2034100): Investigate ways to not require this. This handles the parsing of unitless zeros, as well as ensuring that e.g. calc(anchor(--foo left, 1px) + 10%) round trips (sorting aside), instead of becoming calc(anchor(--foo left, calc(1px)) + 10%).

Fields

node: GenericCalcNode<L>

The parsed fallback value. Stored as a calc node to break the circular reference.

Implementations

Source

impl<L> GenericAnchorFunctionFallback<L>

pub fn new(is_calc_node: bool, node: GenericCalcNode<L>) -> Self

Create a new anchor function fallback value.