pub enum AllowUnitlessZeroAngle {
Yes,
No,
}Expand description
Whether to allow parsing an unitless zero as a valid angle.
This should always be No, except for exceptions like:
https://github.com/w3c/fxtf-drafts/issues/228
See also: https://github.com/w3c/csswg-drafts/issues/1162.
Variants