#[repr(u8)]pub enum TimelineRangeName {
None = 0,
Cover = 1,
Contain = 2,
Entry = 3,
Exit = 4,
EntryCrossing = 5,
ExitCrossing = 6,
Scroll = 7,
}Expand description
The
For now, only view timeline ranges use this type. https://drafts.csswg.org/scroll-animations-1/#view-timelines-ranges
Variants
None = 0
The default value. No timeline range name specified.
Cover = 1
Represents the full range of the view progress timeline
Contain = 2
Represents the range during which the principal box is either fully contained by, or fully covers, its view progress visibility range within the scrollport.
Entry = 3
Represents the range during which the principal box is entering the view progress visibility range.
Exit = 4
Represents the range during which the principal box is exiting the view progress visibility range.
EntryCrossing = 5
Represents the range during which the principal box crosses the end border edge.
ExitCrossing = 6
Represents the range during which the principal box crosses the start border edge.
Scroll = 7
Represents the full range of the scroll container on which the view progress timeline is defined.
Implementations
Sourceimpl TimelineRangeName
impl TimelineRangeName
Sourcepub fn parse<'i, 't>(input: &mut Parser<'i, 't>) -> Result<Self, ParseError<'i>>
pub fn parse<'i, 't>(input: &mut Parser<'i, 't>) -> Result<Self, ParseError<'i>>
Parse this keyword.
Sourcepub fn from_ident(ident: &str) -> Result<Self, ()>
pub fn from_ident(ident: &str) -> Result<Self, ()>
Parse this keyword from a string slice.