AnimationRangeValue

Type Alias AnimationRangeValue 

pub type AnimationRangeValue = GenericAnimationRangeValue<LengthPercentage>;
The internal value for animation-range-start and animation-range-end.

Aliased Type

#[repr(C)]
pub struct AnimationRangeValue { pub name: TimelineRangeName, pub lp: Optional<LengthPercentage>, }

Fields

name: TimelineRangeName

The specific timeline range. If it is None, the animation range only has length-percentage component.

lp: Optional<LengthPercentage>

Used to measure the specific point from the start of the named timeline. This is set to None only for normal keyword. Otherwise, we should always set it to Some().