pub fn parse_namespace<'i, 't>(
namespaces: &FxHashMap<Prefix, Namespace>,
input: &mut Parser<'i, 't>,
allow_non_registered: bool,
) -> Result<(Prefix, ParsedNamespace), ParseError<'i>>Expand description
Try to parse a namespace and return it if parsed, or none if there was not one present