pub enum LengthPercentage {
Length(NoCalcLength),
Percentage(Percentage),
Calc(Box<CalcLengthPercentage>),
}Expand description
A <length-percentage> value. This can be either a <length>, a
<percentage>, or a combination of both via calc().
https://drafts.csswg.org/css-values-4/#typedef-length-percentage
Variants
Implementations
Sourceimpl LengthPercentage
impl LengthPercentage
Sourcepub fn zero_percent() -> LengthPercentage
pub fn zero_percent() -> LengthPercentage
Returns a 0% value.
Sourcepub fn hundred_percent() -> LengthPercentage
pub fn hundred_percent() -> LengthPercentage
Returns a 100% value.
Sourcepub fn parse_quirky<'i, 't>(
context: &ParserContext<'_>,
input: &mut Parser<'i, 't>,
allow_quirks: AllowQuirks,
) -> Result<Self, ParseError<'i>>
pub fn parse_quirky<'i, 't>( context: &ParserContext<'_>, input: &mut Parser<'i, 't>, allow_quirks: AllowQuirks, ) -> Result<Self, ParseError<'i>>
Parses allowing the unitless length quirk. https://quirks.spec.whatwg.org/#the-unitless-length-quirk
Sourcepub fn parse_quirky_with_anchor_functions<'i, 't>(
context: &ParserContext<'_>,
input: &mut Parser<'i, 't>,
allow_quirks: AllowQuirks,
) -> Result<Self, ParseError<'i>>
pub fn parse_quirky_with_anchor_functions<'i, 't>( context: &ParserContext<'_>, input: &mut Parser<'i, 't>, allow_quirks: AllowQuirks, ) -> Result<Self, ParseError<'i>>
Parses allowing the unitless length quirk, as well as allowing
anchor-positioning related functions, anchor() and anchor-size().
Sourcepub fn parse_non_negative_with_anchor_size<'i, 't>(
context: &ParserContext<'_>,
input: &mut Parser<'i, 't>,
allow_quirks: AllowQuirks,
) -> Result<Self, ParseError<'i>>
pub fn parse_non_negative_with_anchor_size<'i, 't>( context: &ParserContext<'_>, input: &mut Parser<'i, 't>, allow_quirks: AllowQuirks, ) -> Result<Self, ParseError<'i>>
Parses non-negative length, allowing the unitless length quirk,
as well as allowing anchor-size().
Sourcepub fn parse_non_negative<'i, 't>(
context: &ParserContext<'_>,
input: &mut Parser<'i, 't>,
) -> Result<Self, ParseError<'i>>
pub fn parse_non_negative<'i, 't>( context: &ParserContext<'_>, input: &mut Parser<'i, 't>, ) -> Result<Self, ParseError<'i>>
Parse a non-negative length.
FIXME(emilio): This should be not public and we should use NonNegativeLengthPercentage instead.
Sourcepub fn parse_non_negative_quirky<'i, 't>(
context: &ParserContext<'_>,
input: &mut Parser<'i, 't>,
allow_quirks: AllowQuirks,
) -> Result<Self, ParseError<'i>>
pub fn parse_non_negative_quirky<'i, 't>( context: &ParserContext<'_>, input: &mut Parser<'i, 't>, allow_quirks: AllowQuirks, ) -> Result<Self, ParseError<'i>>
Parse a non-negative length, with quirks.