#[repr(C)]pub struct TextEdge {
pub over: TextEdgeKeyword,
pub under: TextEdgeKeyword,
}Expand description
The line-fit-edge and
text-box-edge properties.
The first value specifies the text over edge; the second value specifies the text under edge. If only one value is specified, both edges are assigned that same keyword if possible; else text is assumed as the missing value.
https://drafts.csswg.org/css-inline-3/#typedef-text-edge
Fields
over: TextEdgeKeywordFont metric to use for the text over edge.
under: TextEdgeKeywordFont metric to use for the text under edge.