Module applicable_declarations

Module applicable_declarations 

Applicable declarations management.

Structs

ApplicableDeclarationBlock
A property declaration together with its precedence among rules of equal specificity so that we can sort them.
CascadePriority
The cascade-level+layer order of this declaration.
ScopeProximity
Proximity to the scope root.

Enums

RevertKind
The kind of revert that we’re applying.

Type Aliases

ApplicableDeclarationList
List of applicable declarations. This is a transient structure that shuttles declarations between selector matching and inserting into the rule tree, and therefore we want to avoid heap-allocation where possible.