StylesheetInvalidationSet

Struct StylesheetInvalidationSet 

pub struct StylesheetInvalidationSet {
    pub cascade_data_difference: CascadeDataDifference,
    /* private fields */
}
A set of invalidations due to stylesheet changes.

TODO(emilio): We might be able to do the same analysis for media query changes too (or even selector changes?) specially now that we take the cascade data difference into account.

Fields

cascade_data_difference: CascadeDataDifference

The difference between the old and new cascade data, incrementally collected until flush() returns it.

Implementations

Source

impl StylesheetInvalidationSet

pub fn new() -> Self

Create an empty StylesheetInvalidationSet.

pub fn invalidate_fully(&mut self)

Mark the DOM tree styles’ as fully invalid.

pub fn collect_invalidations_for<S>( &mut self, device: &Device, custom_media: &CustomMediaMap, stylesheet: &S, guard: &SharedRwLockReadGuard<'_>, )

Analyze the given stylesheet, and collect invalidations from their rules, in order to avoid doing a full restyle when we style the document next time.

pub fn is_empty(&self) -> bool

Returns whether there’s no invalidation to process.

pub fn process_style<E>(&self, root: E, snapshots: Option<&SnapshotMap>) -> bool
where E: TElement,

Processes the style invalidation set, invalidating elements as needed. Returns true if any style invalidations occurred.

pub fn rule_changed<S>( &mut self, stylesheet: &S, rule: &CssRule, guard: &SharedRwLockReadGuard<'_>, device: &Device, quirks_mode: QuirksMode, custom_media: &CustomMediaMap, change_kind: RuleChangeKind, ancestors: &[CssRuleRef<'_>], )

Collects invalidations for a given CSS rule, if not fully invalid already.