pub struct StylesheetInvalidationSet {
pub cascade_data_difference: CascadeDataDifference,
/* private fields */
}Expand description
A set of invalidations due to stylesheet changes.
TODO(emilio): We might be able to do the same analysis for media query changes too (or even selector changes?) specially now that we take the cascade data difference into account.
Fields
cascade_data_difference: CascadeDataDifferenceThe difference between the old and new cascade data, incrementally collected until flush() returns it.
Implementations
Sourceimpl StylesheetInvalidationSet
impl StylesheetInvalidationSet
Sourcepub fn invalidate_fully(&mut self)
pub fn invalidate_fully(&mut self)
Mark the DOM tree styles’ as fully invalid.
Sourcepub fn collect_invalidations_for<S>(
&mut self,
device: &Device,
custom_media: &CustomMediaMap,
stylesheet: &S,
guard: &SharedRwLockReadGuard<'_>,
)where
S: StylesheetInDocument,
pub fn collect_invalidations_for<S>(
&mut self,
device: &Device,
custom_media: &CustomMediaMap,
stylesheet: &S,
guard: &SharedRwLockReadGuard<'_>,
)where
S: StylesheetInDocument,
Analyze the given stylesheet, and collect invalidations from their rules, in order to avoid doing a full restyle when we style the document next time.
Sourcepub fn process_style<E>(&self, root: E, snapshots: Option<&SnapshotMap>) -> boolwhere
E: TElement,
pub fn process_style<E>(&self, root: E, snapshots: Option<&SnapshotMap>) -> boolwhere
E: TElement,
Processes the style invalidation set, invalidating elements as needed. Returns true if any style invalidations occurred.
Sourcepub fn rule_changed<S>(
&mut self,
stylesheet: &S,
rule: &CssRule,
guard: &SharedRwLockReadGuard<'_>,
device: &Device,
quirks_mode: QuirksMode,
custom_media: &CustomMediaMap,
change_kind: RuleChangeKind,
ancestors: &[CssRuleRef<'_>],
)where
S: StylesheetInDocument,
pub fn rule_changed<S>(
&mut self,
stylesheet: &S,
rule: &CssRule,
guard: &SharedRwLockReadGuard<'_>,
device: &Device,
quirks_mode: QuirksMode,
custom_media: &CustomMediaMap,
change_kind: RuleChangeKind,
ancestors: &[CssRuleRef<'_>],
)where
S: StylesheetInDocument,
Collects invalidations for a given CSS rule, if not fully invalid already.