LonghandId

Enum LonghandId 

#[repr(u16)]
pub enum LonghandId {
Show 247 variants AlignItems = 0, AlignmentBaseline = 1, AspectRatio = 2, BackfaceVisibility = 3, BaselineSource = 4, BorderCollapse = 5, BorderImageRepeat = 6, BoxSizing = 7, CaptionSide = 8, Clear = 9, ColumnCount = 10, ColumnSpan = 11, Contain = 12, ContainerType = 13, Direction = 14, Display = 15, EmptyCells = 16, FlexDirection = 17, FlexWrap = 18, Float = 19, FontKerning = 20, FontLanguageOverride = 21, FontOpticalSizing = 22, FontStretch = 23, FontStyle = 24, FontSynthesisWeight = 25, FontVariantCaps = 26, FontVariantEastAsian = 27, FontVariantLigatures = 28, FontVariantNumeric = 29, FontVariantPosition = 30, FontWeight = 31, GridAutoFlow = 32, ImageRendering = 33, Isolation = 34, JustifyItems = 35, LineBreak = 36, ListStylePosition = 37, MaskType = 38, MixBlendMode = 39, ObjectFit = 40, Opacity = 41, Order = 42, OutlineStyle = 43, OverflowWrap = 44, PointerEvents = 45, Position = 46, PositionArea = 47, ServoTopLayer = 48, TableLayout = 49, TextAlign = 50, TextAlignLast = 51, TextDecorationLine = 52, TextDecorationStyle = 53, TextJustify = 54, TextRendering = 55, TextTransform = 56, TextWrapMode = 57, TransformStyle = 58, UnicodeBidi = 59, UserSelect = 60, Visibility = 61, WebkitTextSecurity = 62, WhiteSpaceCollapse = 63, WordBreak = 64, WritingMode = 65, ZIndex = 66, Zoom = 67, AlignContent = 68, JustifyContent = 69, FlexGrow = 70, FlexShrink = 71, AlignSelf = 72, JustifySelf = 73, OverflowBlock = 74, OverflowInline = 75, OverflowX = 76, OverflowY = 77, BorderBlockEndStyle = 78, BorderBlockStartStyle = 79, BorderBottomStyle = 80, BorderInlineEndStyle = 81, BorderInlineStartStyle = 82, BorderLeftStyle = 83, BorderRightStyle = 84, BorderTopStyle = 85, AnimationComposition = 86, AnimationDelay = 87, AnimationDirection = 88, AnimationDuration = 89, AnimationFillMode = 90, AnimationIterationCount = 91, AnimationName = 92, AnimationPlayState = 93, AnimationRangeEnd = 94, AnimationRangeStart = 95, AnimationTimeline = 96, AnimationTimingFunction = 97, BackdropFilter = 98, BackgroundAttachment = 99, BackgroundBlendMode = 100, BackgroundClip = 101, BackgroundImage = 102, BackgroundOrigin = 103, BackgroundPositionX = 104, BackgroundPositionY = 105, BackgroundRepeat = 106, BackgroundSize = 107, BaselineShift = 108, BorderImageOutset = 109, BorderImageSlice = 110, BorderImageWidth = 111, BorderSpacing = 112, BoxShadow = 113, CaretColor = 114, Clip = 115, ClipPath = 116, Color = 117, ColorScheme = 118, ColumnWidth = 119, ContainerName = 120, Content = 121, CounterIncrement = 122, CounterReset = 123, Cursor = 124, Filter = 125, FlexBasis = 126, FontFamily = 127, FontFeatureSettings = 128, FontSize = 129, FontVariationSettings = 130, GridTemplateAreas = 131, LetterSpacing = 132, LineHeight = 133, ListStyleType = 134, MaskClip = 135, MaskComposite = 136, MaskImage = 137, MaskMode = 138, MaskOrigin = 139, MaskPositionX = 140, MaskPositionY = 141, MaskRepeat = 142, MaskSize = 143, OffsetPath = 144, OutlineOffset = 145, OverflowClipMargin = 146, Perspective = 147, PositionTryFallbacks = 148, Quotes = 149, Rotate = 150, Scale = 151, TabSize = 152, TextIndent = 153, TextOverflow = 154, TextShadow = 155, Transform = 156, TransformOrigin = 157, TransitionBehavior = 158, TransitionDelay = 159, TransitionDuration = 160, TransitionProperty = 161, TransitionTimingFunction = 162, Translate = 163, ViewTransitionClass = 164, ViewTransitionName = 165, WillChange = 166, WordSpacing = 167, XLang = 168, ObjectPosition = 169, PerspectiveOrigin = 170, GridTemplateColumns = 171, GridTemplateRows = 172, BorderImageSource = 173, ListStyleImage = 174, GridAutoColumns = 175, GridAutoRows = 176, ColumnGap = 177, RowGap = 178, GridColumnEnd = 179, GridColumnStart = 180, GridRowEnd = 181, GridRowStart = 182, MaxBlockSize = 183, MaxHeight = 184, MaxInlineSize = 185, MaxWidth = 186, BorderBottomLeftRadius = 187, BorderBottomRightRadius = 188, BorderEndEndRadius = 189, BorderEndStartRadius = 190, BorderStartEndRadius = 191, BorderStartStartRadius = 192, BorderTopLeftRadius = 193, BorderTopRightRadius = 194, Bottom = 195, InsetBlockEnd = 196, InsetBlockStart = 197, InsetInlineEnd = 198, InsetInlineStart = 199, Left = 200, Right = 201, Top = 202, MarginBlockEnd = 203, MarginBlockStart = 204, MarginBottom = 205, MarginInlineEnd = 206, MarginInlineStart = 207, MarginLeft = 208, MarginRight = 209, MarginTop = 210, PaddingBlockEnd = 211, PaddingBlockStart = 212, PaddingBottom = 213, PaddingInlineEnd = 214, PaddingInlineStart = 215, PaddingLeft = 216, PaddingRight = 217, PaddingTop = 218, BlockSize = 219, Height = 220, InlineSize = 221, MinBlockSize = 222, MinHeight = 223, MinInlineSize = 224, MinWidth = 225, Width = 226, BorderBlockEndWidth = 227, BorderBlockStartWidth = 228, BorderBottomWidth = 229, BorderInlineEndWidth = 230, BorderInlineStartWidth = 231, BorderLeftWidth = 232, BorderRightWidth = 233, BorderTopWidth = 234, OutlineWidth = 235, BackgroundColor = 236, BorderBlockEndColor = 237, BorderBlockStartColor = 238, BorderBottomColor = 239, BorderInlineEndColor = 240, BorderInlineStartColor = 241, BorderLeftColor = 242, BorderRightColor = 243, BorderTopColor = 244, OutlineColor = 245, TextDecorationColor = 246,
}
An identifier for a given longhand property.

Variants



AlignItems = 0

align-items



AlignmentBaseline = 1

alignment-baseline



AspectRatio = 2

aspect-ratio



BackfaceVisibility = 3

backface-visibility



BaselineSource = 4

baseline-source



BorderCollapse = 5

border-collapse



BorderImageRepeat = 6

border-image-repeat



BoxSizing = 7

box-sizing



CaptionSide = 8

caption-side



Clear = 9

clear



ColumnCount = 10

column-count



ColumnSpan = 11

column-span



Contain = 12

contain



ContainerType = 13

container-type



Direction = 14

direction



Display = 15

display



EmptyCells = 16

empty-cells



FlexDirection = 17

flex-direction



FlexWrap = 18

flex-wrap



Float = 19

float



FontKerning = 20

font-kerning



FontLanguageOverride = 21

font-language-override



FontOpticalSizing = 22

font-optical-sizing



FontStretch = 23

font-stretch



FontStyle = 24

font-style



FontSynthesisWeight = 25

font-synthesis-weight



FontVariantCaps = 26

font-variant-caps



FontVariantEastAsian = 27

font-variant-east-asian



FontVariantLigatures = 28

font-variant-ligatures



FontVariantNumeric = 29

font-variant-numeric



FontVariantPosition = 30

font-variant-position



FontWeight = 31

font-weight



GridAutoFlow = 32

grid-auto-flow



ImageRendering = 33

image-rendering



Isolation = 34

isolation



JustifyItems = 35

justify-items



LineBreak = 36

line-break



ListStylePosition = 37

list-style-position



MaskType = 38

mask-type



MixBlendMode = 39

mix-blend-mode



ObjectFit = 40

object-fit



Opacity = 41

opacity



Order = 42

order



OutlineStyle = 43

outline-style



OverflowWrap = 44

overflow-wrap



PointerEvents = 45

pointer-events



Position = 46

position



PositionArea = 47

position-area



ServoTopLayer = 48

-servo-top-layer



TableLayout = 49

table-layout



TextAlign = 50

text-align



TextAlignLast = 51

text-align-last



TextDecorationLine = 52

text-decoration-line



TextDecorationStyle = 53

text-decoration-style



TextJustify = 54

text-justify



TextRendering = 55

text-rendering



TextTransform = 56

text-transform



TextWrapMode = 57

text-wrap-mode



TransformStyle = 58

transform-style



UnicodeBidi = 59

unicode-bidi



UserSelect = 60

user-select



Visibility = 61

visibility



WebkitTextSecurity = 62

-webkit-text-security



WhiteSpaceCollapse = 63

white-space-collapse



WordBreak = 64

word-break



WritingMode = 65

writing-mode



ZIndex = 66

z-index



Zoom = 67

zoom



AlignContent = 68

align-content



JustifyContent = 69

justify-content



FlexGrow = 70

flex-grow



FlexShrink = 71

flex-shrink



AlignSelf = 72

align-self



JustifySelf = 73

justify-self



OverflowBlock = 74

overflow-block



OverflowInline = 75

overflow-inline



OverflowX = 76

overflow-x



OverflowY = 77

overflow-y



BorderBlockEndStyle = 78

border-block-end-style



BorderBlockStartStyle = 79

border-block-start-style



BorderBottomStyle = 80

border-bottom-style



BorderInlineEndStyle = 81

border-inline-end-style



BorderInlineStartStyle = 82

border-inline-start-style



BorderLeftStyle = 83

border-left-style



BorderRightStyle = 84

border-right-style



BorderTopStyle = 85

border-top-style



AnimationComposition = 86

animation-composition



AnimationDelay = 87

animation-delay



AnimationDirection = 88

animation-direction



AnimationDuration = 89

animation-duration



AnimationFillMode = 90

animation-fill-mode



AnimationIterationCount = 91

animation-iteration-count



AnimationName = 92

animation-name



AnimationPlayState = 93

animation-play-state



AnimationRangeEnd = 94

animation-range-end



AnimationRangeStart = 95

animation-range-start



AnimationTimeline = 96

animation-timeline



AnimationTimingFunction = 97

animation-timing-function



BackdropFilter = 98

backdrop-filter



BackgroundAttachment = 99

background-attachment



BackgroundBlendMode = 100

background-blend-mode



BackgroundClip = 101

background-clip



BackgroundImage = 102

background-image



BackgroundOrigin = 103

background-origin



BackgroundPositionX = 104

background-position-x



BackgroundPositionY = 105

background-position-y



BackgroundRepeat = 106

background-repeat



BackgroundSize = 107

background-size



BaselineShift = 108

baseline-shift



BorderImageOutset = 109

border-image-outset



BorderImageSlice = 110

border-image-slice



BorderImageWidth = 111

border-image-width



BorderSpacing = 112

border-spacing



BoxShadow = 113

box-shadow



CaretColor = 114

caret-color



Clip = 115

clip



ClipPath = 116

clip-path



Color = 117

color



ColorScheme = 118

color-scheme



ColumnWidth = 119

column-width



ContainerName = 120

container-name



Content = 121

content



CounterIncrement = 122

counter-increment



CounterReset = 123

counter-reset



Cursor = 124

cursor



Filter = 125

filter



FlexBasis = 126

flex-basis



FontFamily = 127

font-family



FontFeatureSettings = 128

font-feature-settings



FontSize = 129

font-size



FontVariationSettings = 130

font-variation-settings



GridTemplateAreas = 131

grid-template-areas



LetterSpacing = 132

letter-spacing



LineHeight = 133

line-height



ListStyleType = 134

list-style-type



MaskClip = 135

mask-clip



MaskComposite = 136

mask-composite



MaskImage = 137

mask-image



MaskMode = 138

mask-mode



MaskOrigin = 139

mask-origin



MaskPositionX = 140

mask-position-x



MaskPositionY = 141

mask-position-y



MaskRepeat = 142

mask-repeat



MaskSize = 143

mask-size



OffsetPath = 144

offset-path



OutlineOffset = 145

outline-offset



OverflowClipMargin = 146

overflow-clip-margin



Perspective = 147

perspective



PositionTryFallbacks = 148

position-try-fallbacks



Quotes = 149

quotes



Rotate = 150

rotate



Scale = 151

scale



TabSize = 152

tab-size



TextIndent = 153

text-indent



TextOverflow = 154

text-overflow



TextShadow = 155

text-shadow



Transform = 156

transform



TransformOrigin = 157

transform-origin



TransitionBehavior = 158

transition-behavior



TransitionDelay = 159

transition-delay



TransitionDuration = 160

transition-duration



TransitionProperty = 161

transition-property



TransitionTimingFunction = 162

transition-timing-function



Translate = 163

translate



ViewTransitionClass = 164

view-transition-class



ViewTransitionName = 165

view-transition-name



WillChange = 166

will-change



WordSpacing = 167

word-spacing



XLang = 168

-x-lang



ObjectPosition = 169

object-position



PerspectiveOrigin = 170

perspective-origin



GridTemplateColumns = 171

grid-template-columns



GridTemplateRows = 172

grid-template-rows



BorderImageSource = 173

border-image-source



ListStyleImage = 174

list-style-image



GridAutoColumns = 175

grid-auto-columns



GridAutoRows = 176

grid-auto-rows



ColumnGap = 177

column-gap



RowGap = 178

row-gap



GridColumnEnd = 179

grid-column-end



GridColumnStart = 180

grid-column-start



GridRowEnd = 181

grid-row-end



GridRowStart = 182

grid-row-start



MaxBlockSize = 183

max-block-size



MaxHeight = 184

max-height



MaxInlineSize = 185

max-inline-size



MaxWidth = 186

max-width



BorderBottomLeftRadius = 187

border-bottom-left-radius



BorderBottomRightRadius = 188

border-bottom-right-radius



BorderEndEndRadius = 189

border-end-end-radius



BorderEndStartRadius = 190

border-end-start-radius



BorderStartEndRadius = 191

border-start-end-radius



BorderStartStartRadius = 192

border-start-start-radius



BorderTopLeftRadius = 193

border-top-left-radius



BorderTopRightRadius = 194

border-top-right-radius



Bottom = 195

bottom



InsetBlockEnd = 196

inset-block-end



InsetBlockStart = 197

inset-block-start



InsetInlineEnd = 198

inset-inline-end



InsetInlineStart = 199

inset-inline-start



Left = 200

left



Right = 201

right



Top = 202

top



MarginBlockEnd = 203

margin-block-end



MarginBlockStart = 204

margin-block-start



MarginBottom = 205

margin-bottom



MarginInlineEnd = 206

margin-inline-end



MarginInlineStart = 207

margin-inline-start



MarginLeft = 208

margin-left



MarginRight = 209

margin-right



MarginTop = 210

margin-top



PaddingBlockEnd = 211

padding-block-end



PaddingBlockStart = 212

padding-block-start



PaddingBottom = 213

padding-bottom



PaddingInlineEnd = 214

padding-inline-end



PaddingInlineStart = 215

padding-inline-start



PaddingLeft = 216

padding-left



PaddingRight = 217

padding-right



PaddingTop = 218

padding-top



BlockSize = 219

block-size



Height = 220

height



InlineSize = 221

inline-size



MinBlockSize = 222

min-block-size



MinHeight = 223

min-height



MinInlineSize = 224

min-inline-size



MinWidth = 225

min-width



Width = 226

width



BorderBlockEndWidth = 227

border-block-end-width



BorderBlockStartWidth = 228

border-block-start-width



BorderBottomWidth = 229

border-bottom-width



BorderInlineEndWidth = 230

border-inline-end-width



BorderInlineStartWidth = 231

border-inline-start-width



BorderLeftWidth = 232

border-left-width



BorderRightWidth = 233

border-right-width



BorderTopWidth = 234

border-top-width



OutlineWidth = 235

outline-width



BackgroundColor = 236

background-color



BorderBlockEndColor = 237

border-block-end-color



BorderBlockStartColor = 238

border-block-start-color



BorderBottomColor = 239

border-bottom-color



BorderInlineEndColor = 240

border-inline-end-color



BorderInlineStartColor = 241

border-inline-start-color



BorderLeftColor = 242

border-left-color



BorderRightColor = 243

border-right-color



BorderTopColor = 244

border-top-color



OutlineColor = 245

outline-color



TextDecorationColor = 246

text-decoration-color

Implementations

Source

impl LonghandId

pub fn shorthands(self) -> NonCustomPropertyIterator<ShorthandId>

Returns an iterator over all the shorthands that include this longhand.

pub fn to_physical(self, wm: WritingMode) -> Self

If this is a logical property, return the corresponding physical one in the given writing mode. Otherwise, return unchanged.

pub fn logical_group(self) -> Option<LogicalGroupId>

Return the logical group of this longhand property.

pub fn flags(self) -> PropertyFlags

Returns PropertyFlags for given longhand property.

Source

impl LonghandId

pub fn name(&self) -> &'static str

Get the name of this longhand property.

pub fn inherited(self) -> bool

Returns whether the longhand property is inherited by default.

pub fn zoom_dependent(self) -> bool

Returns whether the longhand property is zoom-dependent.

pub fn ignored_when_document_colors_disabled(self) -> bool

Returns true if the property is one that is ignored when document colors are disabled.

pub fn is_or_is_longhand_of(self, non_custom: NonCustomPropertyId) -> bool

Returns whether this longhand is non_custom or is a longhand of it.

pub fn is_longhand_of(self, shorthand: ShorthandId) -> bool

Returns whether this longhand is a longhand of shorthand.

pub fn is_animatable(self) -> bool

Returns whether this property is animatable.

pub fn is_discrete_animatable(self) -> bool

Returns whether this property is animatable in a discrete way.

pub fn is_logical(self) -> bool

Return whether this property is logical.