#[repr(u16)]pub enum LonghandId {
Show 233 variants
AlignItems = 0,
AlignmentBaseline = 1,
AspectRatio = 2,
BackfaceVisibility = 3,
BaselineSource = 4,
BorderCollapse = 5,
BorderImageRepeat = 6,
BoxSizing = 7,
CaptionSide = 8,
Clear = 9,
ColumnCount = 10,
ColumnSpan = 11,
Contain = 12,
ContainerType = 13,
Direction = 14,
Display = 15,
EmptyCells = 16,
FlexDirection = 17,
FlexWrap = 18,
Float = 19,
FontKerning = 20,
FontLanguageOverride = 21,
FontOpticalSizing = 22,
FontStretch = 23,
FontStyle = 24,
FontSynthesisWeight = 25,
FontVariantCaps = 26,
FontWeight = 27,
GridAutoFlow = 28,
ImageRendering = 29,
Isolation = 30,
JustifyItems = 31,
LineBreak = 32,
ListStylePosition = 33,
MixBlendMode = 34,
ObjectFit = 35,
Opacity = 36,
Order = 37,
OutlineStyle = 38,
OverflowWrap = 39,
PointerEvents = 40,
Position = 41,
PositionArea = 42,
ServoTopLayer = 43,
TableLayout = 44,
TextAlign = 45,
TextAlignLast = 46,
TextDecorationLine = 47,
TextDecorationStyle = 48,
TextJustify = 49,
TextRendering = 50,
TextTransform = 51,
TextWrapMode = 52,
TransformStyle = 53,
UnicodeBidi = 54,
UserSelect = 55,
Visibility = 56,
WebkitTextSecurity = 57,
WhiteSpaceCollapse = 58,
WordBreak = 59,
WritingMode = 60,
ZIndex = 61,
Zoom = 62,
AlignContent = 63,
JustifyContent = 64,
FlexGrow = 65,
FlexShrink = 66,
AlignSelf = 67,
JustifySelf = 68,
OverflowBlock = 69,
OverflowInline = 70,
OverflowX = 71,
OverflowY = 72,
BorderBlockEndStyle = 73,
BorderBlockStartStyle = 74,
BorderBottomStyle = 75,
BorderInlineEndStyle = 76,
BorderInlineStartStyle = 77,
BorderLeftStyle = 78,
BorderRightStyle = 79,
BorderTopStyle = 80,
AnimationComposition = 81,
AnimationDelay = 82,
AnimationDirection = 83,
AnimationDuration = 84,
AnimationFillMode = 85,
AnimationIterationCount = 86,
AnimationName = 87,
AnimationPlayState = 88,
AnimationRangeEnd = 89,
AnimationRangeStart = 90,
AnimationTimeline = 91,
AnimationTimingFunction = 92,
BackdropFilter = 93,
BackgroundAttachment = 94,
BackgroundBlendMode = 95,
BackgroundClip = 96,
BackgroundImage = 97,
BackgroundOrigin = 98,
BackgroundPositionX = 99,
BackgroundPositionY = 100,
BackgroundRepeat = 101,
BackgroundSize = 102,
BaselineShift = 103,
BorderImageOutset = 104,
BorderImageSlice = 105,
BorderImageWidth = 106,
BorderSpacing = 107,
BoxShadow = 108,
CaretColor = 109,
Clip = 110,
ClipPath = 111,
Color = 112,
ColorScheme = 113,
ColumnWidth = 114,
ContainerName = 115,
Content = 116,
CounterIncrement = 117,
CounterReset = 118,
Cursor = 119,
Filter = 120,
FlexBasis = 121,
FontFamily = 122,
FontSize = 123,
FontVariationSettings = 124,
GridTemplateAreas = 125,
LetterSpacing = 126,
LineHeight = 127,
ListStyleType = 128,
MaskImage = 129,
OffsetPath = 130,
OutlineOffset = 131,
OverflowClipMargin = 132,
Perspective = 133,
PositionTryFallbacks = 134,
Quotes = 135,
Rotate = 136,
Scale = 137,
TabSize = 138,
TextIndent = 139,
TextOverflow = 140,
TextShadow = 141,
Transform = 142,
TransformOrigin = 143,
TransitionBehavior = 144,
TransitionDelay = 145,
TransitionDuration = 146,
TransitionProperty = 147,
TransitionTimingFunction = 148,
Translate = 149,
ViewTransitionClass = 150,
ViewTransitionName = 151,
WillChange = 152,
WordSpacing = 153,
XLang = 154,
ObjectPosition = 155,
PerspectiveOrigin = 156,
GridTemplateColumns = 157,
GridTemplateRows = 158,
BorderImageSource = 159,
ListStyleImage = 160,
GridAutoColumns = 161,
GridAutoRows = 162,
ColumnGap = 163,
RowGap = 164,
GridColumnEnd = 165,
GridColumnStart = 166,
GridRowEnd = 167,
GridRowStart = 168,
MaxBlockSize = 169,
MaxHeight = 170,
MaxInlineSize = 171,
MaxWidth = 172,
BorderBottomLeftRadius = 173,
BorderBottomRightRadius = 174,
BorderEndEndRadius = 175,
BorderEndStartRadius = 176,
BorderStartEndRadius = 177,
BorderStartStartRadius = 178,
BorderTopLeftRadius = 179,
BorderTopRightRadius = 180,
Bottom = 181,
InsetBlockEnd = 182,
InsetBlockStart = 183,
InsetInlineEnd = 184,
InsetInlineStart = 185,
Left = 186,
Right = 187,
Top = 188,
MarginBlockEnd = 189,
MarginBlockStart = 190,
MarginBottom = 191,
MarginInlineEnd = 192,
MarginInlineStart = 193,
MarginLeft = 194,
MarginRight = 195,
MarginTop = 196,
PaddingBlockEnd = 197,
PaddingBlockStart = 198,
PaddingBottom = 199,
PaddingInlineEnd = 200,
PaddingInlineStart = 201,
PaddingLeft = 202,
PaddingRight = 203,
PaddingTop = 204,
BlockSize = 205,
Height = 206,
InlineSize = 207,
MinBlockSize = 208,
MinHeight = 209,
MinInlineSize = 210,
MinWidth = 211,
Width = 212,
BorderBlockEndWidth = 213,
BorderBlockStartWidth = 214,
BorderBottomWidth = 215,
BorderInlineEndWidth = 216,
BorderInlineStartWidth = 217,
BorderLeftWidth = 218,
BorderRightWidth = 219,
BorderTopWidth = 220,
OutlineWidth = 221,
BackgroundColor = 222,
BorderBlockEndColor = 223,
BorderBlockStartColor = 224,
BorderBottomColor = 225,
BorderInlineEndColor = 226,
BorderInlineStartColor = 227,
BorderLeftColor = 228,
BorderRightColor = 229,
BorderTopColor = 230,
OutlineColor = 231,
TextDecorationColor = 232,
}Expand description
An identifier for a given longhand property.
Variants
AlignItems = 0
align-items
AlignmentBaseline = 1
alignment-baseline
AspectRatio = 2
aspect-ratio
BackfaceVisibility = 3
backface-visibility
BaselineSource = 4
baseline-source
BorderCollapse = 5
border-collapse
BorderImageRepeat = 6
border-image-repeat
BoxSizing = 7
box-sizing
CaptionSide = 8
caption-side
Clear = 9
clear
ColumnCount = 10
column-count
ColumnSpan = 11
column-span
Contain = 12
contain
ContainerType = 13
container-type
Direction = 14
direction
Display = 15
display
EmptyCells = 16
empty-cells
FlexDirection = 17
flex-direction
FlexWrap = 18
flex-wrap
Float = 19
float
FontKerning = 20
font-kerning
FontLanguageOverride = 21
font-language-override
FontOpticalSizing = 22
font-optical-sizing
FontStretch = 23
font-stretch
FontStyle = 24
font-style
FontSynthesisWeight = 25
font-synthesis-weight
FontVariantCaps = 26
font-variant-caps
FontWeight = 27
font-weight
GridAutoFlow = 28
grid-auto-flow
ImageRendering = 29
image-rendering
Isolation = 30
isolation
JustifyItems = 31
justify-items
LineBreak = 32
line-break
ListStylePosition = 33
list-style-position
MixBlendMode = 34
mix-blend-mode
ObjectFit = 35
object-fit
Opacity = 36
opacity
Order = 37
order
OutlineStyle = 38
outline-style
OverflowWrap = 39
overflow-wrap
PointerEvents = 40
pointer-events
Position = 41
position
PositionArea = 42
position-area
ServoTopLayer = 43
-servo-top-layer
TableLayout = 44
table-layout
TextAlign = 45
text-align
TextAlignLast = 46
text-align-last
TextDecorationLine = 47
text-decoration-line
TextDecorationStyle = 48
text-decoration-style
TextJustify = 49
text-justify
TextRendering = 50
text-rendering
TextTransform = 51
text-transform
TextWrapMode = 52
text-wrap-mode
TransformStyle = 53
transform-style
UnicodeBidi = 54
unicode-bidi
UserSelect = 55
user-select
Visibility = 56
visibility
WebkitTextSecurity = 57
-webkit-text-security
WhiteSpaceCollapse = 58
white-space-collapse
WordBreak = 59
word-break
WritingMode = 60
writing-mode
ZIndex = 61
z-index
Zoom = 62
zoom
AlignContent = 63
align-content
JustifyContent = 64
justify-content
FlexGrow = 65
flex-grow
FlexShrink = 66
flex-shrink
AlignSelf = 67
align-self
JustifySelf = 68
justify-self
OverflowBlock = 69
overflow-block
OverflowInline = 70
overflow-inline
OverflowX = 71
overflow-x
OverflowY = 72
overflow-y
BorderBlockEndStyle = 73
border-block-end-style
BorderBlockStartStyle = 74
border-block-start-style
BorderBottomStyle = 75
border-bottom-style
BorderInlineEndStyle = 76
border-inline-end-style
BorderInlineStartStyle = 77
border-inline-start-style
BorderLeftStyle = 78
border-left-style
BorderRightStyle = 79
border-right-style
BorderTopStyle = 80
border-top-style
AnimationComposition = 81
animation-composition
AnimationDelay = 82
animation-delay
AnimationDirection = 83
animation-direction
AnimationDuration = 84
animation-duration
AnimationFillMode = 85
animation-fill-mode
AnimationIterationCount = 86
animation-iteration-count
AnimationName = 87
animation-name
AnimationPlayState = 88
animation-play-state
AnimationRangeEnd = 89
animation-range-end
AnimationRangeStart = 90
animation-range-start
AnimationTimeline = 91
animation-timeline
AnimationTimingFunction = 92
animation-timing-function
BackdropFilter = 93
backdrop-filter
BackgroundAttachment = 94
background-attachment
BackgroundBlendMode = 95
background-blend-mode
BackgroundClip = 96
background-clip
BackgroundImage = 97
background-image
BackgroundOrigin = 98
background-origin
BackgroundPositionX = 99
background-position-x
BackgroundPositionY = 100
background-position-y
BackgroundRepeat = 101
background-repeat
BackgroundSize = 102
background-size
BaselineShift = 103
baseline-shift
BorderImageOutset = 104
border-image-outset
BorderImageSlice = 105
border-image-slice
BorderImageWidth = 106
border-image-width
BorderSpacing = 107
border-spacing
BoxShadow = 108
box-shadow
CaretColor = 109
caret-color
Clip = 110
clip
ClipPath = 111
clip-path
Color = 112
color
ColorScheme = 113
color-scheme
ColumnWidth = 114
column-width
ContainerName = 115
container-name
Content = 116
content
CounterIncrement = 117
counter-increment
CounterReset = 118
counter-reset
Cursor = 119
cursor
Filter = 120
filter
FlexBasis = 121
flex-basis
FontFamily = 122
font-family
FontSize = 123
font-size
FontVariationSettings = 124
font-variation-settings
GridTemplateAreas = 125
grid-template-areas
LetterSpacing = 126
letter-spacing
LineHeight = 127
line-height
ListStyleType = 128
list-style-type
MaskImage = 129
mask-image
OffsetPath = 130
offset-path
OutlineOffset = 131
outline-offset
OverflowClipMargin = 132
overflow-clip-margin
Perspective = 133
perspective
PositionTryFallbacks = 134
position-try-fallbacks
Quotes = 135
quotes
Rotate = 136
rotate
Scale = 137
scale
TabSize = 138
tab-size
TextIndent = 139
text-indent
TextOverflow = 140
text-overflow
TextShadow = 141
text-shadow
Transform = 142
transform
TransformOrigin = 143
transform-origin
TransitionBehavior = 144
transition-behavior
TransitionDelay = 145
transition-delay
TransitionDuration = 146
transition-duration
TransitionProperty = 147
transition-property
TransitionTimingFunction = 148
transition-timing-function
Translate = 149
translate
ViewTransitionClass = 150
view-transition-class
ViewTransitionName = 151
view-transition-name
WillChange = 152
will-change
WordSpacing = 153
word-spacing
XLang = 154
-x-lang
ObjectPosition = 155
object-position
PerspectiveOrigin = 156
perspective-origin
GridTemplateColumns = 157
grid-template-columns
GridTemplateRows = 158
grid-template-rows
BorderImageSource = 159
border-image-source
ListStyleImage = 160
list-style-image
GridAutoColumns = 161
grid-auto-columns
GridAutoRows = 162
grid-auto-rows
ColumnGap = 163
column-gap
RowGap = 164
row-gap
GridColumnEnd = 165
grid-column-end
GridColumnStart = 166
grid-column-start
GridRowEnd = 167
grid-row-end
GridRowStart = 168
grid-row-start
MaxBlockSize = 169
max-block-size
MaxHeight = 170
max-height
MaxInlineSize = 171
max-inline-size
MaxWidth = 172
max-width
BorderBottomLeftRadius = 173
border-bottom-left-radius
BorderBottomRightRadius = 174
border-bottom-right-radius
BorderEndEndRadius = 175
border-end-end-radius
BorderEndStartRadius = 176
border-end-start-radius
BorderStartEndRadius = 177
border-start-end-radius
BorderStartStartRadius = 178
border-start-start-radius
BorderTopLeftRadius = 179
border-top-left-radius
BorderTopRightRadius = 180
border-top-right-radius
Bottom = 181
bottom
InsetBlockEnd = 182
inset-block-end
InsetBlockStart = 183
inset-block-start
InsetInlineEnd = 184
inset-inline-end
InsetInlineStart = 185
inset-inline-start
Left = 186
left
Right = 187
right
Top = 188
top
MarginBlockEnd = 189
margin-block-end
MarginBlockStart = 190
margin-block-start
MarginBottom = 191
margin-bottom
MarginInlineEnd = 192
margin-inline-end
MarginInlineStart = 193
margin-inline-start
MarginLeft = 194
margin-left
MarginRight = 195
margin-right
MarginTop = 196
margin-top
PaddingBlockEnd = 197
padding-block-end
PaddingBlockStart = 198
padding-block-start
PaddingBottom = 199
padding-bottom
PaddingInlineEnd = 200
padding-inline-end
PaddingInlineStart = 201
padding-inline-start
PaddingLeft = 202
padding-left
PaddingRight = 203
padding-right
PaddingTop = 204
padding-top
BlockSize = 205
block-size
Height = 206
height
InlineSize = 207
inline-size
MinBlockSize = 208
min-block-size
MinHeight = 209
min-height
MinInlineSize = 210
min-inline-size
MinWidth = 211
min-width
Width = 212
width
BorderBlockEndWidth = 213
border-block-end-width
BorderBlockStartWidth = 214
border-block-start-width
BorderBottomWidth = 215
border-bottom-width
BorderInlineEndWidth = 216
border-inline-end-width
BorderInlineStartWidth = 217
border-inline-start-width
BorderLeftWidth = 218
border-left-width
BorderRightWidth = 219
border-right-width
BorderTopWidth = 220
border-top-width
OutlineWidth = 221
outline-width
BackgroundColor = 222
background-color
BorderBlockEndColor = 223
border-block-end-color
BorderBlockStartColor = 224
border-block-start-color
BorderBottomColor = 225
border-bottom-color
BorderInlineEndColor = 226
border-inline-end-color
BorderInlineStartColor = 227
border-inline-start-color
BorderLeftColor = 228
border-left-color
BorderRightColor = 229
border-right-color
BorderTopColor = 230
border-top-color
OutlineColor = 231
outline-color
TextDecorationColor = 232
text-decoration-color
Implementations
Sourceimpl LonghandId
impl LonghandId
Sourcepub fn shorthands(self) -> NonCustomPropertyIterator<ShorthandId> ⓘ
pub fn shorthands(self) -> NonCustomPropertyIterator<ShorthandId> ⓘ
Returns an iterator over all the shorthands that include this longhand.
Sourcepub fn to_physical(self, wm: WritingMode) -> Self
pub fn to_physical(self, wm: WritingMode) -> Self
If this is a logical property, return the corresponding physical one in the given writing mode. Otherwise, return unchanged.
Sourcepub fn logical_group(self) -> Option<LogicalGroupId>
pub fn logical_group(self) -> Option<LogicalGroupId>
Return the logical group of this longhand property.
Sourcepub fn flags(self) -> PropertyFlags
pub fn flags(self) -> PropertyFlags
Returns PropertyFlags for given longhand property.
Sourceimpl LonghandId
impl LonghandId
Sourcepub fn zoom_dependent(self) -> bool
pub fn zoom_dependent(self) -> bool
Returns whether the longhand property is zoom-dependent.
Sourcepub fn ignored_when_document_colors_disabled(self) -> bool
pub fn ignored_when_document_colors_disabled(self) -> bool
Returns true if the property is one that is ignored when document colors are disabled.
Sourcepub fn is_or_is_longhand_of(self, non_custom: NonCustomPropertyId) -> bool
pub fn is_or_is_longhand_of(self, non_custom: NonCustomPropertyId) -> bool
Returns whether this longhand is non_custom or is a longhand of it.
Sourcepub fn is_longhand_of(self, shorthand: ShorthandId) -> bool
pub fn is_longhand_of(self, shorthand: ShorthandId) -> bool
Returns whether this longhand is a longhand of shorthand.
Sourcepub fn is_animatable(self) -> bool
pub fn is_animatable(self) -> bool
Returns whether this property is animatable.
Sourcepub fn is_discrete_animatable(self) -> bool
pub fn is_discrete_animatable(self) -> bool
Returns whether this property is animatable in a discrete way.
Sourcepub fn is_logical(self) -> bool
pub fn is_logical(self) -> bool
Return whether this property is logical.