LonghandIdSet

Type Alias LonghandIdSet 

pub type LonghandIdSet = IdSet<LonghandId, { _ }>;
A set of longhand properties.

Aliased Type

pub struct LonghandIdSet { /* private fields */ }

Implementations

Source

impl LonghandIdSet

pub fn margin_properties() -> &'static Self

Returns the set of margin properties, for the purposes of

use counters / warnings.

pub fn border_background_properties() -> &'static Self

Returns the set of border properties for the purpose of disabling native appearance.

pub fn zoom_dependent() -> &'static Self

Returns properties that are zoom dependent (basically, that contain lengths).

pub fn zoom_dependent_inherited_properties() -> &'static Self

Note that it’s different from zoom_dependent(), as this only includes inherited, physical properties.

Source

impl LonghandIdSet

pub fn contains_any_reset(&self) -> bool

Return whether this set contains any reset longhand.