pub type LonghandIdSet = IdSet<LonghandId, { _ }>;Expand description
A set of longhand properties.
Aliased Type
pub struct LonghandIdSet { /* private fields */ }Implementations
Sourceimpl LonghandIdSet
impl LonghandIdSet
Sourcepub fn margin_properties() -> &'static Self
pub fn margin_properties() -> &'static Self
Returns the set of margin properties, for the purposes of
use counters / warnings.
Sourcepub fn border_background_properties() -> &'static Self
pub fn border_background_properties() -> &'static Self
Returns the set of border properties for the purpose of disabling native appearance.
Sourcepub fn zoom_dependent() -> &'static Self
pub fn zoom_dependent() -> &'static Self
Returns properties that are zoom dependent (basically, that contain lengths).
Sourcepub fn zoom_dependent_inherited_properties() -> &'static Self
pub fn zoom_dependent_inherited_properties() -> &'static Self
Note that it’s different from zoom_dependent(), as this only includes inherited, physical properties.
Sourceimpl LonghandIdSet
impl LonghandIdSet
Sourcepub fn contains_any_reset(&self) -> bool
pub fn contains_any_reset(&self) -> bool
Return whether this set contains any reset longhand.