ComputedValue

Type Alias ComputedValue 

pub type ComputedValue = Value<ComputedValueComponent>;
Computed custom property value.

Aliased Type

pub struct ComputedValue {
    pub attribute_tainted: bool,
    /* private fields */
}

Fields

attribute_tainted: bool

Flag indicating whether this value is tainted by an attr().

Implementations

Source

impl ComputedValue

pub fn as_universal(&self) -> Option<&Arc<ComputedPropertyValue>>

Returns the contained variable value if it exists, otherwise None.