pub type ComputedValue = Value<ComputedValueComponent>;Expand description
Computed custom property value.
Aliased Type
pub struct ComputedValue {
pub attribute_tainted: bool,
/* private fields */
}Fields
attribute_tainted: boolFlag indicating whether this value is tainted by an attr().
Implementations
Sourceimpl ComputedValue
impl ComputedValue
Sourcepub fn as_universal(&self) -> Option<&Arc<ComputedPropertyValue>>
pub fn as_universal(&self) -> Option<&Arc<ComputedPropertyValue>>
Returns the contained variable value if it exists, otherwise None.