A data structure to efficiently index structs containing selectors by local name, ids and hash.
Structs
- Maybe
Case Insensitive Hash Map - Wrapper for PrecomputedHashMap that does ASCII-case-insensitive lookup in quirks mode.
- Precomputed
Hasher - A hasher implementation that doesn’t hash anything, because it expects its input to be a suitable u32 hash.
- Selector
Map - Map element data to selector-providing objects for which the last simple selector starts with them.
Traits
- Selector
MapEntry - A trait to abstract over a given selector map entry.
Type Aliases
- Precomputed
Hash Map - A simple alias for a hashmap using PrecomputedHasher.
- Precomputed
Hash Set - A simple alias for a hashset using PrecomputedHasher.
- Relevant
Attributes - A vector of relevant attributes, that can be useful for revalidation.