Module selector_map

Module selector_map 

A data structure to efficiently index structs containing selectors by local name, ids and hash.

Structs

MaybeCaseInsensitiveHashMap
Wrapper for PrecomputedHashMap that does ASCII-case-insensitive lookup in quirks mode.
PrecomputedHasher
A hasher implementation that doesn’t hash anything, because it expects its input to be a suitable u32 hash.
SelectorMap
Map element data to selector-providing objects for which the last simple selector starts with them.

Traits

SelectorMapEntry
A trait to abstract over a given selector map entry.

Type Aliases

PrecomputedHashMap
A simple alias for a hashmap using PrecomputedHasher.
PrecomputedHashSet
A simple alias for a hashset using PrecomputedHasher.
RelevantAttributes
A vector of relevant attributes, that can be useful for revalidation.