pub struct StyleAdjuster<'a, 'b: 'a> { /* private fields */ }Expand description
A struct that implements all the adjustment methods.
NOTE(emilio): If new adjustments are introduced that depend on reset
properties of the parent, you may need tweaking the
ChildCascadeRequirement code in matching.rs.
NOTE(emilio): Also, if new adjustments are introduced that break the following invariant:
Given same tag name, namespace, rules and parent style, two elements would end up with exactly the same style.
Then you need to adjust the lookup_by_rules conditions in the sharing cache.
Implementations
Sourceimpl<'a, 'b: 'a> StyleAdjuster<'a, 'b>
impl<'a, 'b: 'a> StyleAdjuster<'a, 'b>
Sourcepub fn new(style: &'a mut StyleBuilder<'b>) -> Self
pub fn new(style: &'a mut StyleBuilder<'b>) -> Self
Trivially constructs a new StyleAdjuster.
Sourcepub fn adjust<E>(
&mut self,
layout_parent_style: &ComputedValues,
element: Option<E>,
try_tactic: &PositionTryFallbacksTryTactic,
)where
E: TElement,
pub fn adjust<E>(
&mut self,
layout_parent_style: &ComputedValues,
element: Option<E>,
try_tactic: &PositionTryFallbacksTryTactic,
)where
E: TElement,
Adjusts the style to account for various fixups that don’t fit naturally into the cascade.