ToComputedValue

Trait ToComputedValue 

pub trait ToComputedValue {
    type ComputedValue;

    // Required methods
    fn to_computed_value(&self, context: &Context<'_>) -> Self::ComputedValue;
    fn from_computed_value(computed: &Self::ComputedValue) -> Self;
}
A trait to represent the conversion between computed and specified values.

This trait is derivable with #[derive(ToComputedValue)]. The derived implementation just calls ToComputedValue::to_computed_value on each field of the passed value. The deriving code assumes that if the type isn’t generic, then the trait can be implemented as simple Clone::clone calls, this means that a manual implementation with ComputedValue = Self is bogus if it returns anything else than a clone.

Required Associated Types

type ComputedValue

The computed value type we’re going to be converted to.

Required Methods

fn to_computed_value(&self, context: &Context<'_>) -> Self::ComputedValue

Convert a specified value to a computed value, using itself and the data inside the Context.

fn from_computed_value(computed: &Self::ComputedValue) -> Self

Convert a computed value to specified value form.

This will be used for recascading during animation. Such from_computed_valued values should recompute to the same value.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ToComputedValue for ()

Source

type ComputedValue = ()

Source

fn to_computed_value(&self, _: &Context<'_>) -> Self

Source

fn from_computed_value(other: &Self) -> Self

Source

impl ToComputedValue for AllowedNumericType

Source

impl ToComputedValue for Box<str>

Source

type ComputedValue = Box<str>

Source

fn to_computed_value(&self, _: &Context<'_>) -> Self

Source

fn from_computed_value(other: &Self) -> Self

Source

impl ToComputedValue for String

Source

type ComputedValue = String

Source

fn to_computed_value(&self, _: &Context<'_>) -> Self

Source

fn from_computed_value(other: &Self) -> Self

Source

impl ToComputedValue for bool

Source

type ComputedValue = bool

Source

fn to_computed_value(&self, _: &Context<'_>) -> Self

Source

fn from_computed_value(other: &Self) -> Self

Source

impl ToComputedValue for f32

Source

type ComputedValue = f32

Source

fn to_computed_value(&self, _: &Context<'_>) -> Self

Source

fn from_computed_value(other: &Self) -> Self

Source

impl ToComputedValue for i8

Source

type ComputedValue = i8

Source

fn to_computed_value(&self, _: &Context<'_>) -> Self

Source

fn from_computed_value(other: &Self) -> Self

Source

impl ToComputedValue for i32

Source

type ComputedValue = i32

Source

fn to_computed_value(&self, _: &Context<'_>) -> Self

Source

fn from_computed_value(other: &Self) -> Self

Source

impl ToComputedValue for u8

Source

type ComputedValue = u8

Source

fn to_computed_value(&self, _: &Context<'_>) -> Self

Source

fn from_computed_value(other: &Self) -> Self

Source

impl ToComputedValue for u16

Source

type ComputedValue = u16

Source

fn to_computed_value(&self, _: &Context<'_>) -> Self

Source

fn from_computed_value(other: &Self) -> Self

Source

impl ToComputedValue for u32

Source

type ComputedValue = u32

Source

fn to_computed_value(&self, _: &Context<'_>) -> Self

Source

fn from_computed_value(other: &Self) -> Self

Source

impl ToComputedValue for usize

Source

type ComputedValue = usize

Source

fn to_computed_value(&self, _: &Context<'_>) -> Self

Source

fn from_computed_value(other: &Self) -> Self

Source

impl<A, B> ToComputedValue for (A, B)

Source

impl<T> ToComputedValue for Arc<T>
where T: ToComputedValue<ComputedValue = T>,

Source

type ComputedValue = Arc<T>

Source

fn to_computed_value(&self, _: &Context<'_>) -> Self

Source

fn from_computed_value(computed: &Self) -> Self

Source

impl<T> ToComputedValue for Box<T>
where T: ToComputedValue,

Source

impl<T> ToComputedValue for Box<[T]>
where T: ToComputedValue,

Source

impl<T> ToComputedValue for Option<T>
where T: ToComputedValue,

Source

impl<T> ToComputedValue for Size2D<T>
where T: ToComputedValue,

Source

impl<T> ToComputedValue for ThinVec<T>
where T: ToComputedValue,

Source

impl<T> ToComputedValue for Vec<T>
where T: ToComputedValue,

Implementors

Source

impl ToComputedValue for AbsoluteLength

Source

impl ToComputedValue for AlignFlags
where u8: ToComputedValue<ComputedValue = u8>,

Source

impl ToComputedValue for AlignmentBaseline

Source

impl ToComputedValue for AnchorNameIdent

Source

impl ToComputedValue for AnchorSideKeyword

Source

impl ToComputedValue for AnchorSizeKeyword

Source

impl ToComputedValue for Angle

Source

impl ToComputedValue for AngleOrPercentage

Source

impl ToComputedValue for AnimationComposition

Source

impl ToComputedValue for AnimationDirection

Source

impl ToComputedValue for AnimationFillMode

Source

impl ToComputedValue for AnimationIterationCount

Source

impl ToComputedValue for AnimationName

Source

impl ToComputedValue for AnimationPlayState

Source

impl ToComputedValue for Appearance

Source

impl ToComputedValue for ArcSize

Source

impl ToComputedValue for ArcSweep

Source

impl ToComputedValue for Atom

Source

impl ToComputedValue for AtomIdent

Source

impl ToComputedValue for AtomString
where Atom: ToComputedValue<ComputedValue = Atom>,

Source

impl ToComputedValue for Attr
where Prefix: ToComputedValue<ComputedValue = Prefix>, Namespace: ToComputedValue<ComputedValue = Namespace>, Atom: ToComputedValue<ComputedValue = Atom>, AtomString: ToComputedValue<ComputedValue = AtomString>,

Source

impl ToComputedValue for AttrTaintedRange
where usize: ToComputedValue<ComputedValue = usize>,

Source

impl ToComputedValue for AxisPosition<CSSFloat>

Source

impl ToComputedValue for AxisPosition<LengthPercentage>

Source

impl ToComputedValue for BackgroundRepeat

Source

impl ToComputedValue for BackgroundRepeatKeyword

Source

impl ToComputedValue for BaselineShiftKeyword

Source

impl ToComputedValue for BaselineSource

Source

impl ToComputedValue for BasicShapeRect

Source

impl ToComputedValue for BoolInteger
where bool: ToComputedValue<ComputedValue = bool>,

Source

impl ToComputedValue for BoolValue

Source

impl ToComputedValue for BorderImageRepeat

Source

impl ToComputedValue for BorderImageRepeatKeyword

Source

impl ToComputedValue for BorderSideOffset

Source

impl ToComputedValue for BorderSideWidth

Source

impl ToComputedValue for BorderStyle

Source

impl ToComputedValue for BoxShadow

Source

impl ToComputedValue for BreakBetween

Source

impl ToComputedValue for BreakWithin

Source

impl ToComputedValue for CSSPixelLength
where CSSFloat: ToComputedValue<ComputedValue = CSSFloat>,

Source

impl ToComputedValue for CaptionSide

Source

impl ToComputedValue for Clear

Source

impl ToComputedValue for Color

Source

impl ToComputedValue for ColorInterpolationMethod

Source

impl ToComputedValue for ColorMixFlags

Source

impl ToComputedValue for ColorPropertyValue

Source

impl ToComputedValue for ColorScheme

Source

impl ToComputedValue for ColorSchemeFlags
where u8: ToComputedValue<ComputedValue = u8>,

Source

impl ToComputedValue for ColorSpace

Source

impl ToComputedValue for Contain
where u8: ToComputedValue<ComputedValue = u8>,

Source

impl ToComputedValue for ContainerName

Source

impl ToComputedValue for ContainerType
where u8: ToComputedValue<ComputedValue = u8>,

Source

impl ToComputedValue for ContentDistribution
where AlignFlags: ToComputedValue<ComputedValue = AlignFlags>,

Source

impl ToComputedValue for ContentVisibility

Source

impl ToComputedValue for ContextPropertyBits
where u8: ToComputedValue<ComputedValue = u8>,

Source

impl ToComputedValue for ControlReference

Source

impl ToComputedValue for CoordBox

Source

impl ToComputedValue for CounterStyle
where CustomIdent: ToComputedValue<ComputedValue = CustomIdent>, SymbolsType: ToComputedValue<ComputedValue = SymbolsType>, Symbols: ToComputedValue<ComputedValue = Symbols>, AtomString: ToComputedValue<ComputedValue = AtomString>,

Source

impl ToComputedValue for CursorKind

Source

impl ToComputedValue for CustomIdent
where Atom: ToComputedValue<ComputedValue = Atom>,

Source

impl ToComputedValue for DProperty
where SVGPathData: ToComputedValue<ComputedValue = SVGPathData>,

Source

impl ToComputedValue for DashedIdent
where Atom: ToComputedValue<ComputedValue = Atom>,

Source

impl ToComputedValue for DashedIdentAndOrTryTactic

Source

impl ToComputedValue for Display
where u16: ToComputedValue<ComputedValue = u16>,

Source

impl ToComputedValue for DominantBaseline

Source

impl ToComputedValue for FamilyName

Source

impl ToComputedValue for FillRule

Source

impl ToComputedValue for FilterFactor

Source

impl ToComputedValue for Float

Source

impl ToComputedValue for FontDisplay

Source

impl ToComputedValue for style::values::specified::font::FontFamily

Source

impl ToComputedValue for style::values::computed::font::FontFamily
where FontFamilyList: ToComputedValue<ComputedValue = FontFamilyList>, bool: ToComputedValue<ComputedValue = bool>,

Source

impl ToComputedValue for FontFamilyList

Source

impl ToComputedValue for FontFamilyNameSyntax

Source

impl ToComputedValue for FontLanguageOverride
where u32: ToComputedValue<ComputedValue = u32>,

Source

impl ToComputedValue for FontPalette
where Atom: ToComputedValue<ComputedValue = Atom>,

Source

impl ToComputedValue for FontSize

Source

impl ToComputedValue for FontSizeAdjust

Source

impl ToComputedValue for FontSizeKeyword

Source

impl ToComputedValue for FontStretch

Source

impl ToComputedValue for FontStyle

Source

impl ToComputedValue for FontSynthesis

Source

impl ToComputedValue for FontSynthesisStyle

Source

impl ToComputedValue for FontTag
where u32: ToComputedValue<ComputedValue = u32>,

Source

impl ToComputedValue for FontVariantAlternates

Source

impl ToComputedValue for FontVariantEastAsian
where u16: ToComputedValue<ComputedValue = u16>,

Source

impl ToComputedValue for FontVariantLigatures
where u16: ToComputedValue<ComputedValue = u16>,

Source

impl ToComputedValue for FontVariantNumeric
where u8: ToComputedValue<ComputedValue = u8>,

Source

impl ToComputedValue for FontWeight

Source

impl ToComputedValue for ForcedColorAdjust

Source

impl ToComputedValue for GenericFontFamily

Source

impl ToComputedValue for GradientCompatMode

Source

impl ToComputedValue for GradientFlags
where u8: ToComputedValue<ComputedValue = u8>,

Source

impl ToComputedValue for GridAutoFlow
where u8: ToComputedValue<ComputedValue = u8>,

Source

impl ToComputedValue for GridTemplateAreas

Source

impl ToComputedValue for HorizontalPositionKeyword

Source

impl ToComputedValue for HueInterpolationMethod

Source

impl ToComputedValue for HyphenateCharacter
where OwnedStr: ToComputedValue<ComputedValue = OwnedStr>,

Source

impl ToComputedValue for Image

Source

impl ToComputedValue for ImageRendering

Source

impl ToComputedValue for ImageSet

Source

impl ToComputedValue for Impossible

Source

impl ToComputedValue for Inert

Source

impl ToComputedValue for Integer

Source

impl ToComputedValue for ItemPlacement
where AlignFlags: ToComputedValue<ComputedValue = AlignFlags>,

Source

impl ToComputedValue for JustifyItems

Source

impl ToComputedValue for KeyframesName
where Atom: ToComputedValue<ComputedValue = Atom>,

Source

impl ToComputedValue for KeywordInfo

Source

impl ToComputedValue for Length

Source

impl ToComputedValue for LengthPercentage

Source

impl ToComputedValue for LetterSpacing

Source

impl ToComputedValue for LineBreak

Source

impl ToComputedValue for LineDirection

Source

impl ToComputedValue for LineHeight

Source

impl ToComputedValue for LineWidth

Source

impl ToComputedValue for ListStyleType
where CounterStyle: ToComputedValue<ComputedValue = CounterStyle>,

Source

impl ToComputedValue for LonghandId

Source

impl ToComputedValue for MasonryAutoFlow

Source

impl ToComputedValue for MasonryItemOrder

Source

impl ToComputedValue for MasonryPlacement

Source

impl ToComputedValue for MozContextProperties

Source

impl ToComputedValue for MozControlCharacterVisibility

Source

impl ToComputedValue for MozScriptMinSize

Source

impl ToComputedValue for MozScriptSizeMultiplier
where f32: ToComputedValue<ComputedValue = f32>,

Source

impl ToComputedValue for MozTheme

Source

impl ToComputedValue for Multiplier

Source

impl ToComputedValue for NamedArea
where Atom: ToComputedValue<ComputedValue = Atom>, UnsignedRange: ToComputedValue<ComputedValue = UnsignedRange>,

Source

impl ToComputedValue for Namespace

Source

impl ToComputedValue for NoCalcLength

Source

impl ToComputedValue for NonCustomPropertyId
where u16: ToComputedValue<ComputedValue = u16>,

Source

impl ToComputedValue for Number

Source

impl ToComputedValue for NumberOrPercentage

Source

impl ToComputedValue for OffsetRotate

Source

impl ToComputedValue for Opacity

Source

impl ToComputedValue for OutlineStyle
where BorderStyle: ToComputedValue<ComputedValue = BorderStyle>,

Source

impl ToComputedValue for Overflow

Source

impl ToComputedValue for OverflowAnchor

Source

impl ToComputedValue for OverflowClipMarginBox

Source

impl ToComputedValue for OverflowWrap

Source

impl ToComputedValue for OverscrollBehavior

Source

impl ToComputedValue for OwnedStr

Source

impl ToComputedValue for PageName
where CustomIdent: ToComputedValue<ComputedValue = CustomIdent>,

Source

impl ToComputedValue for PageOrientation

Source

impl ToComputedValue for PageSize

Source

impl ToComputedValue for PaintWorklet
where Atom: ToComputedValue<ComputedValue = Atom>,

Source

impl ToComputedValue for Path
where FillRule: ToComputedValue<ComputedValue = FillRule>, SVGPathData: ToComputedValue<ComputedValue = SVGPathData>,

Source

impl ToComputedValue for style::values::specified::percentage::Percentage

Source

impl ToComputedValue for style::values::computed::percentage::Percentage
where CSSFloat: ToComputedValue<ComputedValue = CSSFloat>,

Source

impl ToComputedValue for PointerEvents

Source

impl ToComputedValue for PositionAnchorKeyword
where DashedIdent: ToComputedValue<ComputedValue = DashedIdent>,

Source

impl ToComputedValue for PositionArea

Source

impl ToComputedValue for PositionAreaKeyword

Source

impl ToComputedValue for PositionProperty

Source

impl ToComputedValue for PositionTryFallbacks

Source

impl ToComputedValue for PositionTryFallbacksItem

Source

impl ToComputedValue for PositionTryFallbacksTryTactic

Source

impl ToComputedValue for PositionTryFallbacksTryTacticKeyword

Source

impl ToComputedValue for PositionTryOrder

Source

impl ToComputedValue for PositionVisibility
where u8: ToComputedValue<ComputedValue = u8>,

Source

impl ToComputedValue for Prefix

Source

impl ToComputedValue for PrintColorAdjust

Source

impl ToComputedValue for QuoteList

Source

impl ToComputedValue for QuotePair
where OwnedStr: ToComputedValue<ComputedValue = OwnedStr>,

Source

impl ToComputedValue for Quotes
where QuoteList: ToComputedValue<ComputedValue = QuoteList>,

Source

impl ToComputedValue for RaySize

Source

impl ToComputedValue for Resize

Source

impl ToComputedValue for Resolution

Source

impl ToComputedValue for RubyPosition

Source

impl ToComputedValue for SVGPaintOrder
where u8: ToComputedValue<ComputedValue = u8>,

Source

impl ToComputedValue for SVGPathData

Source

impl ToComputedValue for ScopedNameList

Source

impl ToComputedValue for ScrollAxis

Source

impl ToComputedValue for ScrollFunction
where Scroller: ToComputedValue<ComputedValue = Scroller>, ScrollAxis: ToComputedValue<ComputedValue = ScrollAxis>,

Source

impl ToComputedValue for ScrollSnapAlign

Source

impl ToComputedValue for ScrollSnapAlignKeyword

Source

impl ToComputedValue for ScrollSnapAxis

Source

impl ToComputedValue for ScrollSnapStop

Source

impl ToComputedValue for ScrollSnapStrictness

Source

impl ToComputedValue for ScrollSnapType

Source

impl ToComputedValue for ScrollbarGutter
where u8: ToComputedValue<ComputedValue = u8>,

Source

impl ToComputedValue for Scroller

Source

impl ToComputedValue for SelfAlignment
where AlignFlags: ToComputedValue<ComputedValue = AlignFlags>,

Source

impl ToComputedValue for ShapeBox

Source

impl ToComputedValue for ShapeExtent

Source

impl ToComputedValue for ShapeGeometryBox
where ShapeBox: ToComputedValue<ComputedValue = ShapeBox>,

Source

impl ToComputedValue for ShorthandId

Source

impl ToComputedValue for SimpleShadow

Source

impl ToComputedValue for SingleFontFamily

Source

impl ToComputedValue for SpecifiedFontStyle

Source

impl ToComputedValue for SpecifiedUrl

Source

impl ToComputedValue for style::properties::generated::longhands::animation_composition::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::animation_delay::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::animation_direction::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::animation_duration::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::animation_fill_mode::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::animation_iteration_count::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::animation_name::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::animation_play_state::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::animation_range_end::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::animation_range_start::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::animation_timeline::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::animation_timing_function::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::backdrop_filter::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::background_attachment::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::background_blend_mode::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::background_clip::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::background_image::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::background_origin::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::background_position_x::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::background_position_y::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::background_repeat::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::background_size::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::box_shadow::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::filter::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::mask_clip::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::mask_composite::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::mask_image::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::mask_mode::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::mask_origin::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::mask_position_x::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::mask_position_y::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::mask_repeat::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::mask_size::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::text_shadow::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::transition_behavior::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::transition_delay::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::transition_duration::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::transition_property::SpecifiedValue

Source

impl ToComputedValue for style::properties::generated::longhands::transition_timing_function::SpecifiedValue

Source

impl ToComputedValue for StepPosition

Source

impl ToComputedValue for Symbol
where OwnedStr: ToComputedValue<ComputedValue = OwnedStr>, CustomIdent: ToComputedValue<ComputedValue = CustomIdent>,

Source

impl ToComputedValue for Symbols
where ArcSlice<Symbol>: ToComputedValue<ComputedValue = ArcSlice<Symbol>>,

Source

impl ToComputedValue for SymbolsType

Source

impl ToComputedValue for style::properties::generated::longhands::backface_visibility::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::border_collapse::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::box_sizing::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::column_span::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::direction::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::empty_cells::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::flex_direction::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::flex_wrap::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::font_kerning::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::font_optical_sizing::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::font_variant_caps::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::font_variant_position::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::isolation::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::list_style_position::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::mask_type::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::mix_blend_mode::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::object_fit::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::_servo_top_layer::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::table_layout::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::text_decoration_style::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::text_rendering::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::text_wrap_mode::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::unicode_bidi::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::visibility::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::_webkit_text_security::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::white_space_collapse::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::background_attachment::single_value::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::background_blend_mode::single_value::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::background_clip::single_value::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::background_origin::single_value::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::mask_clip::single_value::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::mask_composite::single_value::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::mask_mode::single_value::computed_value::T

Source

impl ToComputedValue for style::properties::generated::longhands::mask_origin::single_value::computed_value::T

Source

impl ToComputedValue for TemplateAreas

Source

impl ToComputedValue for TemplateAreasArc

Source

impl ToComputedValue for TextAlign

Source

impl ToComputedValue for TextAlignKeyword

Source

impl ToComputedValue for TextAlignLast

Source

impl ToComputedValue for TextAutospace
where u8: ToComputedValue<ComputedValue = u8>,

Source

impl ToComputedValue for TextBoxEdge
where TextEdge: ToComputedValue<ComputedValue = TextEdge>,

Source

impl ToComputedValue for TextBoxTrim
where u8: ToComputedValue<ComputedValue = u8>,

Source

impl ToComputedValue for TextDecorationLine
where u8: ToComputedValue<ComputedValue = u8>,

Source

impl ToComputedValue for TextDecorationSkipInk

Source

impl ToComputedValue for TextEdge

Source

impl ToComputedValue for TextEdgeKeyword

Source

impl ToComputedValue for TextEmphasisFillMode

Source

impl ToComputedValue for TextEmphasisPosition
where u8: ToComputedValue<ComputedValue = u8>,

Source

impl ToComputedValue for TextEmphasisShapeKeyword

Source

impl ToComputedValue for TextEmphasisStyle

Source

impl ToComputedValue for TextJustify

Source

impl ToComputedValue for TextOverflow
where TextOverflowSide: ToComputedValue<ComputedValue = TextOverflowSide>, bool: ToComputedValue<ComputedValue = bool>,

Source

impl ToComputedValue for TextOverflowSide
where AtomString: ToComputedValue<ComputedValue = AtomString>,

Source

impl ToComputedValue for TextTransform
where u8: ToComputedValue<ComputedValue = u8>,

Source

impl ToComputedValue for TextTransformCase

Source

impl ToComputedValue for TextUnderlinePosition
where u8: ToComputedValue<ComputedValue = u8>,

Source

impl ToComputedValue for Time

Source

impl ToComputedValue for TimelineIdent
where DashedIdent: ToComputedValue<ComputedValue = DashedIdent>,

Source

impl ToComputedValue for TimelineRangeName

Source

impl ToComputedValue for TimingFunction

Source

impl ToComputedValue for TimingKeyword

Source

impl ToComputedValue for TouchAction
where u8: ToComputedValue<ComputedValue = u8>,

Source

impl ToComputedValue for TransformBox

Source

impl ToComputedValue for TransformStyle

Source

impl ToComputedValue for TransitionBehavior

Source

impl ToComputedValue for TransitionProperty

Source

impl ToComputedValue for UnsignedRange
where u32: ToComputedValue<ComputedValue = u32>,

Source

impl ToComputedValue for UrlExtraData

Source

impl ToComputedValue for UserFocus

Source

impl ToComputedValue for UserSelect

Source

impl ToComputedValue for VariableValue

Source

impl ToComputedValue for VariantAlternates

Source

impl ToComputedValue for VectorEffect
where u8: ToComputedValue<ComputedValue = u8>,

Source

impl ToComputedValue for VerticalPositionKeyword

Source

impl ToComputedValue for ViewTransitionClassList

Source

impl ToComputedValue for ViewTransitionNameKeyword
where AtomIdent: ToComputedValue<ComputedValue = AtomIdent>,

Source

impl ToComputedValue for WillChange

Source

impl ToComputedValue for WillChangeBits
where u16: ToComputedValue<ComputedValue = u16>,

Source

impl ToComputedValue for WordBreak

Source

impl ToComputedValue for WordSpacing

Source

impl ToComputedValue for WritingModeProperty

Source

impl ToComputedValue for XLang
where Atom: ToComputedValue<ComputedValue = Atom>,

Source

impl ToComputedValue for XTextScale

Source

impl ToComputedValue for Zoom

Source

impl<A, B> ToComputedValue for Either<A, B>

Source

impl<Angle, Factor, Length, Shadow, U> ToComputedValue for GenericFilter<Angle, Factor, Length, Shadow, U>

Source

impl<Angle, Number, Length, Integer, LengthPercentage> ToComputedValue for GenericTransformOperation<Angle, Number, Length, Integer, LengthPercentage>

Source

impl<Angle, Position, LengthPercentage, BasicShapeRect> ToComputedValue for GenericBasicShape<Angle, Position, LengthPercentage, BasicShapeRect>
where Angle: ToComputedValue, Position: ToComputedValue, LengthPercentage: ToComputedValue, BasicShapeRect: ToComputedValue, GenericPathOrShapeFunction<Angle, Position, LengthPercentage>: ToComputedValue<ComputedValue = GenericPathOrShapeFunction<<Angle as ToComputedValue>::ComputedValue, <Position as ToComputedValue>::ComputedValue, <LengthPercentage as ToComputedValue>::ComputedValue>>,

Source

impl<Angle, Position, LengthPercentage> ToComputedValue for GenericPathOrShapeFunction<Angle, Position, LengthPercentage>
where Angle: ToComputedValue, Position: ToComputedValue, LengthPercentage: ToComputedValue, Shape<Angle, Position, LengthPercentage>: ToComputedValue<ComputedValue = Shape<<Angle as ToComputedValue>::ComputedValue, <Position as ToComputedValue>::ComputedValue, <LengthPercentage as ToComputedValue>::ComputedValue>>,

Source

impl<Angle, Position, LengthPercentage> ToComputedValue for GenericShapeCommand<Angle, Position, LengthPercentage>
where Angle: ToComputedValue, Position: ToComputedValue, LengthPercentage: ToComputedValue, AxisEndPoint<LengthPercentage>: ToComputedValue<ComputedValue = AxisEndPoint<<LengthPercentage as ToComputedValue>::ComputedValue>>,

Source

impl<Angle, Position, LengthPercentage> ToComputedValue for Shape<Angle, Position, LengthPercentage>
where Angle: ToComputedValue, Position: ToComputedValue, LengthPercentage: ToComputedValue, OwnedSlice<GenericShapeCommand<Angle, Position, LengthPercentage>>: ToComputedValue<ComputedValue = OwnedSlice<GenericShapeCommand<<Angle as ToComputedValue>::ComputedValue, <Position as ToComputedValue>::ComputedValue, <LengthPercentage as ToComputedValue>::ComputedValue>>>,

Source

impl<Angle, Position> ToComputedValue for GenericRayFunction<Angle, Position>
where Angle: ToComputedValue, Position: ToComputedValue,

Source

impl<BasicShape, I> ToComputedValue for GenericShapeOutside<BasicShape, I>
where BasicShape: ToComputedValue, I: ToComputedValue,

Source

impl<BasicShape, U> ToComputedValue for GenericClipPath<BasicShape, U>
where BasicShape: ToComputedValue, U: ToComputedValue,

Source

impl<C, U> ToComputedValue for GenericSVGPaintKind<C, U>

Source

impl<C> ToComputedValue for GenericCaretColor<C>
where C: ToComputedValue,

Source

impl<C> ToComputedValue for GenericColorOrAuto<C>
where C: ToComputedValue,

Source

impl<C> ToComputedValue for GenericSVGPaintFallback<C>
where C: ToComputedValue,

Source

impl<Color, Percentage> ToComputedValue for GenericColorMix<Color, Percentage>
where Color: ToComputedValue, Percentage: ToComputedValue,

Source

impl<Color, Percentage> ToComputedValue for GenericColorMixItem<Color, Percentage>
where Color: ToComputedValue, Percentage: ToComputedValue,

Source

impl<Color, T> ToComputedValue for ColorStop<Color, T>

Source

impl<Color, T> ToComputedValue for GenericGradientItem<Color, T>

Source

impl<Color, Url> ToComputedValue for GenericSVGPaint<Color, Url>
where Color: ToComputedValue, Url: ToComputedValue,

Source

impl<Color> ToComputedValue for GenericScrollbarColor<Color>
where Color: ToComputedValue,

Source

impl<Component> ToComputedValue for ComponentList<Component>
where Component: ToComputedValue,

Source

impl<Component> ToComputedValue for Value<Component>
where Component: ToComputedValue,

Source

impl<Component> ToComputedValue for ValueInner<Component>
where Component: ToComputedValue,

Source

impl<Factor> ToComputedValue for GenericFontSizeAdjust<Factor>
where Factor: ToComputedValue,

Source

impl<Fallback> ToComputedValue for GenericAnchorSizeFunction<Fallback>
where Fallback: ToComputedValue,

Source

impl<Function> ToComputedValue for GenericOffsetPath<Function>
where Function: ToComputedValue,

Source

impl<H, V, Depth> ToComputedValue for GenericTransformOrigin<H, V, Depth>

Source

impl<H, V> ToComputedValue for GenericOffsetPosition<H, V>

Source

impl<H, V> ToComputedValue for GenericPosition<H, V>

Source

impl<I, C> ToComputedValue for GenericCrossFadeImage<I, C>

Source

impl<I> ToComputedValue for GenericContentItem<I>
where I: ToComputedValue,

Source

impl<I> ToComputedValue for GenericCounterIncrement<I>
where I: ToComputedValue,

Source

impl<I> ToComputedValue for GenericCounterReset<I>
where I: ToComputedValue,

Source

impl<I> ToComputedValue for GenericCounterSet<I>
where I: ToComputedValue,

Source

impl<I> ToComputedValue for GenericCounters<I>
where I: ToComputedValue,

Source

impl<I> ToComputedValue for GenericLineClamp<I>
where I: ToComputedValue,

Source

impl<I> ToComputedValue for GenericLineNameList<I>
where I: ToComputedValue,

Source

impl<I> ToComputedValue for GenericLineNameListValue<I>
where I: ToComputedValue,

Source

impl<I> ToComputedValue for GenericNameRepeat<I>
where I: ToComputedValue,

Source

impl<I> ToComputedValue for GenericZIndex<I>
where I: ToComputedValue,

Source

impl<I> ToComputedValue for MozPrefFeatureValue<I>
where I: ToComputedValue,

Source

impl<Image, Color, Percentage> ToComputedValue for GenericCrossFade<Image, Color, Percentage>
where Image: ToComputedValue, Color: ToComputedValue, Percentage: ToComputedValue,

Source

impl<Image, Color, Percentage> ToComputedValue for GenericCrossFadeElement<Image, Color, Percentage>
where Image: ToComputedValue, Color: ToComputedValue, Percentage: ToComputedValue,

Source

impl<Image, Number> ToComputedValue for GenericCursorImage<Image, Number>
where Image: ToComputedValue, Number: ToComputedValue,

Source

impl<Image, Resolution> ToComputedValue for GenericImageSetItem<Image, Resolution>
where Image: ToComputedValue, Resolution: ToComputedValue,

Source

impl<Image> ToComputedValue for GenericContent<Image>
where Image: ToComputedValue,

Source

impl<Image> ToComputedValue for GenericContentItems<Image>
where Image: ToComputedValue,

Source

impl<Image> ToComputedValue for GenericCursor<Image>
where Image: ToComputedValue,

Source

impl<Integer> ToComputedValue for FeatureTagValue<Integer>
where Integer: ToComputedValue,

Source

impl<Integer> ToComputedValue for GenericCounterPair<Integer>
where Integer: ToComputedValue,

Source

impl<Integer> ToComputedValue for GenericGridLine<Integer>
where Integer: ToComputedValue,

Source

impl<Integer> ToComputedValue for GenericHyphenateLimitChars<Integer>
where Integer: ToComputedValue,

Source

impl<Integer> ToComputedValue for RepeatCount<Integer>
where Integer: ToComputedValue,

Source

impl<L, I> ToComputedValue for GenericGridTemplateComponent<L, I>

Source

impl<L, I> ToComputedValue for GenericTrackRepeat<L, I>

Source

impl<L, N> ToComputedValue for GenericLengthOrNumber<L, N>

Source

impl<L> ToComputedValue for GenericBorderCornerRadius<L>
where L: ToComputedValue,

Source

impl<L> ToComputedValue for GenericBorderSpacing<L>
where L: ToComputedValue,

Source

impl<L> ToComputedValue for GenericContainIntrinsicSize<L>
where L: ToComputedValue,

Source

impl<L> ToComputedValue for GenericOverflowClipMargin<L>
where L: ToComputedValue,

Source

impl<L> ToComputedValue for GenericPerspectiveFunction<L>
where L: ToComputedValue,

Source

impl<L> ToComputedValue for GenericSVGLength<L>
where L: ToComputedValue,

Source

impl<L> ToComputedValue for GenericSVGStrokeDashArray<L>
where L: ToComputedValue,

Source

impl<L> ToComputedValue for GenericTextDecorationInset<L>
where L: ToComputedValue,

Source

impl<L> ToComputedValue for GenericTextDecorationLength<L>
where L: ToComputedValue,

Source

impl<L> ToComputedValue for GenericTrackBreadth<L>
where L: ToComputedValue,

Source

impl<L> ToComputedValue for GenericTrackSize<L>
where L: ToComputedValue,

Source

impl<L> ToComputedValue for style::values::generics::size::Size2D<L>
where L: ToComputedValue,

Source

impl<LP, N> ToComputedValue for GenericBorderImageSideWidth<LP, N>

Source

impl<LP> ToComputedValue for GenericMargin<LP>
where LP: ToComputedValue,

Source

impl<Length, Number, Percentage, LengthPercentage, Color, Image, Url, Integer, Angle, Time, Resolution, TransformFunction> ToComputedValue for GenericValueComponent<Length, Number, Percentage, LengthPercentage, Color, Image, Url, Integer, Angle, Time, Resolution, TransformFunction>
where Length: ToComputedValue, Number: ToComputedValue, Percentage: ToComputedValue, LengthPercentage: ToComputedValue, Color: ToComputedValue, Image: ToComputedValue, Url: ToComputedValue, Integer: ToComputedValue, Angle: ToComputedValue, Time: ToComputedValue, Resolution: ToComputedValue, TransformFunction: ToComputedValue,

Source

impl<LengthOrAuto> ToComputedValue for GenericClipRect<LengthOrAuto>
where LengthOrAuto: ToComputedValue,

Source

impl<LengthPercent> ToComputedValue for GenericAnimationRangeEnd<LengthPercent>
where LengthPercent: ToComputedValue,

Source

impl<LengthPercent> ToComputedValue for GenericAnimationRangeStart<LengthPercent>
where LengthPercent: ToComputedValue,

Source

impl<LengthPercent> ToComputedValue for GenericAnimationRangeValue<LengthPercent>
where LengthPercent: ToComputedValue,

Source

impl<LengthPercent> ToComputedValue for GenericAnimationTimeline<LengthPercent>
where LengthPercent: ToComputedValue,

Source

impl<LengthPercent> ToComputedValue for GenericBackgroundSize<LengthPercent>
where LengthPercent: ToComputedValue,

Source

impl<LengthPercent> ToComputedValue for GenericLengthPercentageOrAuto<LengthPercent>
where LengthPercent: ToComputedValue,

Source

impl<LengthPercent> ToComputedValue for GenericLengthPercentageOrNormal<LengthPercent>
where LengthPercent: ToComputedValue,

Source

impl<LengthPercent> ToComputedValue for GenericMaxSize<LengthPercent>
where LengthPercent: ToComputedValue,

Source

impl<LengthPercent> ToComputedValue for GenericSize<LengthPercent>
where LengthPercent: ToComputedValue,

Source

impl<LengthPercent> ToComputedValue for GenericViewFunction<LengthPercent>
where LengthPercent: ToComputedValue,

Source

impl<LengthPercent> ToComputedValue for GenericViewTimelineInset<LengthPercent>
where LengthPercent: ToComputedValue,

Source

impl<LengthPercentage, Integer> ToComputedValue for GenericTrackList<LengthPercentage, Integer>
where LengthPercentage: ToComputedValue, Integer: ToComputedValue,

Source

impl<LengthPercentage, Integer> ToComputedValue for GenericTrackListValue<LengthPercentage, Integer>
where LengthPercentage: ToComputedValue, Integer: ToComputedValue,

Source

impl<LengthPercentage, Length> ToComputedValue for GenericTranslate<LengthPercentage, Length>
where LengthPercentage: Zero + ZeroNoPercent + ToComputedValue, Length: Zero + ToComputedValue, <LengthPercentage as ToComputedValue>::ComputedValue: Zero + ZeroNoPercent, <Length as ToComputedValue>::ComputedValue: Zero,

Source

impl<LengthPercentage> ToComputedValue for ArcRadii<LengthPercentage>
where LengthPercentage: ToComputedValue,

Source

impl<LengthPercentage> ToComputedValue for AxisEndPoint<LengthPercentage>
where LengthPercentage: ToComputedValue, AxisPosition<LengthPercentage>: ToComputedValue<ComputedValue = AxisPosition<<LengthPercentage as ToComputedValue>::ComputedValue>>,

Source

impl<LengthPercentage> ToComputedValue for CoordinatePair<LengthPercentage>
where LengthPercentage: ToComputedValue,

Source

impl<LengthPercentage> ToComputedValue for GenericBaselineShift<LengthPercentage>
where LengthPercentage: ToComputedValue,

Source

impl<LengthPercentage> ToComputedValue for GenericBorderRadius<LengthPercentage>
where LengthPercentage: ToComputedValue,

Source

impl<LengthPercentage> ToComputedValue for GenericInsetRect<LengthPercentage>
where LengthPercentage: ToComputedValue,

Source

impl<LengthPercentage> ToComputedValue for GenericPolygon<LengthPercentage>
where LengthPercentage: ToComputedValue,

Source

impl<LengthPercentage> ToComputedValue for GenericShapeRadius<LengthPercentage>
where LengthPercentage: ToComputedValue,

Source

impl<LengthPercentage> ToComputedValue for GenericTextIndent<LengthPercentage>
where LengthPercentage: ToComputedValue,

Source

impl<LengthPercentage> ToComputedValue for PolygonCoord<LengthPercentage>
where LengthPercentage: ToComputedValue,

Source

impl<LengthPercentage> ToComputedValue for RelativeControlPoint<LengthPercentage>
where LengthPercentage: ToComputedValue,

Source

impl<LineDirection, Length, LengthPercentage, Position, Angle, AngleOrPercentage, Color> ToComputedValue for GenericGradient<LineDirection, Length, LengthPercentage, Position, Angle, AngleOrPercentage, Color>
where LineDirection: ToComputedValue, Length: ToComputedValue, LengthPercentage: ToComputedValue, Position: ToComputedValue, Angle: ToComputedValue, AngleOrPercentage: ToComputedValue, Color: ToComputedValue,

Source

impl<N> ToComputedValue for GenericAspectRatio<N>
where N: ToComputedValue,

Source

impl<N> ToComputedValue for NumberOrAuto<N>
where N: ToComputedValue,

Source

impl<N> ToComputedValue for PreferredRatio<N>
where N: ToComputedValue,

Source

impl<N> ToComputedValue for Ratio<N>
where N: ToComputedValue,

Source

impl<NonNegativeLength, NonNegativeLengthPercentage> ToComputedValue for GenericEndingShape<NonNegativeLength, NonNegativeLengthPercentage>
where NonNegativeLength: ToComputedValue, NonNegativeLengthPercentage: ToComputedValue,

Source

type ComputedValue = GenericEndingShape<<NonNegativeLength as ToComputedValue>::ComputedValue, <NonNegativeLengthPercentage as ToComputedValue>::ComputedValue>

Source

impl<NonNegativeLength> ToComputedValue for GenericCircle<NonNegativeLength>
where NonNegativeLength: ToComputedValue,

Source

impl<NonNegativeLength> ToComputedValue for GenericPerspective<NonNegativeLength>
where NonNegativeLength: ToComputedValue,

Source

impl<NonNegativeLengthPercentage> ToComputedValue for GenericEllipse<NonNegativeLengthPercentage>
where NonNegativeLengthPercentage: ToComputedValue,

Source

type ComputedValue = GenericEllipse<<NonNegativeLengthPercentage as ToComputedValue>::ComputedValue>

Source

impl<Number, Angle> ToComputedValue for GenericRotate<Number, Angle>
where Number: ToComputedValue, Angle: ToComputedValue,

Source

impl<Number, Integer> ToComputedValue for GenericInitialLetter<Number, Integer>
where Number: ToComputedValue, Integer: ToComputedValue,

Source

impl<Number> ToComputedValue for GenericScale<Number>
where Number: ToComputedValue,

Source

impl<Number> ToComputedValue for VariationValue<Number>
where Number: ToComputedValue,

Source

impl<NumberOrPercentage> ToComputedValue for GenericBorderImageSlice<NumberOrPercentage>
where NumberOrPercentage: ToComputedValue,

Source

impl<OpacityType> ToComputedValue for GenericSVGOpacity<OpacityType>
where OpacityType: ToComputedValue,

Source

impl<P, LP> ToComputedValue for GenericInset<P, LP>

Source

impl<P> ToComputedValue for GenericAnchorSide<P>
where P: ToComputedValue,

Source

impl<Percentage, Fallback> ToComputedValue for GenericAnchorFunction<Percentage, Fallback>
where Percentage: ToComputedValue, Fallback: ToComputedValue,

Source

impl<Pos> ToComputedValue for GenericPositionOrAuto<Pos>
where Pos: ToComputedValue,

Source

impl<Position, LengthPercentage> ToComputedValue for Circle<Position, LengthPercentage>
where Position: ToComputedValue, LengthPercentage: ToComputedValue,

Source

impl<Position, LengthPercentage> ToComputedValue for CommandEndPoint<Position, LengthPercentage>
where Position: ToComputedValue, LengthPercentage: ToComputedValue,

Source

impl<Position, LengthPercentage> ToComputedValue for ControlPoint<Position, LengthPercentage>
where Position: ToComputedValue, LengthPercentage: ToComputedValue,

Source

impl<Position, LengthPercentage> ToComputedValue for Ellipse<Position, LengthPercentage>
where Position: ToComputedValue, LengthPercentage: ToComputedValue,

Source

impl<PositiveInteger> ToComputedValue for GenericColumnCount<PositiveInteger>
where PositiveInteger: ToComputedValue,

Source

impl<R> ToComputedValue for GenericClipRectOrAuto<R>
where R: ToComputedValue,

Source

impl<S: Side> ToComputedValue for PositionComponent<S>

Source

impl<S> ToComputedValue for GenericFlexBasis<S>
where S: ToComputedValue,

Source

impl<S> ToComputedValue for OriginComponent<S>
where S: Side,

Source

impl<Shapes, RayFunction, U> ToComputedValue for GenericOffsetPathFunction<Shapes, RayFunction, U>
where Shapes: ToComputedValue, RayFunction: ToComputedValue, U: ToComputedValue,

Source

impl<T> ToComputedValue for ArcSlice<T>
where T: ToComputedValue<ComputedValue = T>,

Source

impl<T> ToComputedValue for FontSettings<T>

Source

impl<T> ToComputedValue for GenericAnimationDuration<T>
where T: ToComputedValue,

Source

impl<T> ToComputedValue for GenericImplicitGridTracks<T>
where T: ToComputedValue,

Source

impl<T> ToComputedValue for GenericMatrix3D<T>
where T: ToComputedValue,

Source

impl<T> ToComputedValue for GenericMatrix<T>
where T: ToComputedValue,

Source

impl<T> ToComputedValue for GenericTransform<T>
where T: ToComputedValue,

Source

impl<T> ToComputedValue for GreaterThanOrEqualToOne<T>
where T: ToComputedValue,

Source

impl<T> ToComputedValue for NonNegative<T>
where T: ToComputedValue,

Source

impl<T> ToComputedValue for Optional<T>
where T: ToComputedValue,

Source

impl<T> ToComputedValue for OwnedSlice<T>
where T: ToComputedValue,

Source

impl<T> ToComputedValue for Rect<T>
where T: ToComputedValue,

Source

impl<T> ToComputedValue for TreeScoped<T>

Source

impl<T> ToComputedValue for ZeroToOne<T>
where T: ToComputedValue,

Source

impl<U> ToComputedValue for GenericUrlOrNone<U>
where U: ToComputedValue,