#[repr(C)]pub struct GenericAnimationRangeValue<LengthPercent> {
pub name: TimelineRangeName,
pub lp: Optional<LengthPercent>,
}Expand description
A value for animation-range-start or animation-range-end.
https://drafts.csswg.org/scroll-animations-1/#animation-range-start https://drafts.csswg.org/scroll-animations-1/#animation-range-end
Fields
name: TimelineRangeNameThe specific timeline range. If it is None, the animation range only has length-percentage component.
lp: Optional<LengthPercent>Used to measure the specific point from the start of the named timeline. This is set to
None only for normal keyword. Otherwise, we should always set it to Some().
Implementations
Sourceimpl<LengthPercent> AnimationRangeValue<LengthPercent>
impl<LengthPercent> AnimationRangeValue<LengthPercent>
Sourcepub fn length_percentage(lp: LengthPercent) -> Self
pub fn length_percentage(lp: LengthPercent) -> Self
Returns Self as a LengthPercentage.
Sourcepub fn timeline_range(name: TimelineRangeName, lp: LengthPercent) -> Self
pub fn timeline_range(name: TimelineRangeName, lp: LengthPercent) -> Self
Returns Self as a tuple of TimelineRangeName range name and LengthPercentage.